@@ -9,18 +9,18 @@ class DataContextKey(metaclass=ABCMeta):
     """
 
     @abstractmethod
-    def to_tuple(self):
+    def to_tuple(self) -> None:
         pass
 
     @classmethod
     def from_tuple(cls, tuple_):
         return cls(*tuple_)
 
-    def to_fixed_length_tuple(self):
+    def to_fixed_length_tuple(self) -> None:
         raise NotImplementedError
 
     @classmethod
-    def from_fixed_length_tuple(cls, tuple_):
+    def from_fixed_length_tuple(cls, tuple_) -> None:
         raise NotImplementedError
 
     def __eq__(self, other):
@@ -62,7 +62,7 @@ class DataContextKey(metaclass=ABCMeta):
 class StringKey(DataContextKey):
     """A simple DataContextKey with just a single string value"""
 
-    def __init__(self, key):
+    def __init__(self, key) -> None:
         self._key = key
 
     def to_tuple(self):
