@@ -473,6 +473,7 @@ anonymized_run_validation_operator_payload_schema = {
     "definitions": {
         "anonymized_string": anonymized_string_schema,
         "anonymized_batch": anonymized_batch_schema,
+        "anonymized_datasource_name": anonymized_datasource_name_schema,
     },
     "type": "object",
     "properties": {
@@ -1013,7 +1014,12 @@ anonymized_usage_statistics_record_schema = {
         {
             "type": "object",
             "properties": {
-                "event": {"enum": ["datasource.sqlalchemy.connect"]},
+                "event": {
+                    "enum": [
+                        "datasource.sqlalchemy.connect",
+                        "execution_engine.sqlalchemy.connect",
+                    ]
+                },
                 "event_payload": {
                     "$ref": "#/definitions/anonymized_datasource_sqlalchemy_connect_payload"
                 },
@@ -1028,6 +1034,8 @@ anonymized_usage_statistics_record_schema = {
                         "data_context.open_data_docs",
                         "data_context.run_checkpoint",
                         "expectation_suite.add_expectation",
+                        "data_context.run_profiler_with_dynamic_arguments",
+                        "data_context.run_profiler_on_data",
                     ],
                 },
                 "event_payload": {"$ref": "#/definitions/empty_payload"},
