@@ -100,7 +100,7 @@ class HtmlSiteStore:
 
     _key_class = SiteSectionIdentifier
 
-    def __init__(self, store_backend=None, runtime_environment=None):
+    def __init__(self, store_backend=None, runtime_environment=None) -> None:
         store_backend_module_name = store_backend.get(
             "module_name", "great_expectations.data_context.store"
         )
@@ -366,7 +366,7 @@ class HtmlSiteStore:
             content_type="text/html; " "charset=utf-8",
         )
 
-    def clean_site(self):
+    def clean_site(self) -> None:
         for _, target_store_backend in self.store_backends.items():
             keys = target_store_backend.list_keys()
             for key in keys:
