@@ -35,7 +35,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
         manually_initialize_store_backend_id: str = "",
         base_public_path=None,
         store_name=None,
-    ):
+    ) -> None:
         super().__init__(
             fixed_length_key=fixed_length_key,
             suppress_store_backend_id=suppress_store_backend_id,
@@ -72,7 +72,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
             self.verify_that_key_to_filepath_operation_is_reversible()
             self._fixed_length_key = True
 
-    def _validate_key(self, key):
+    def _validate_key(self, key) -> None:
         super()._validate_key(key)
 
         for key_element in key:
@@ -86,7 +86,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
                         )
                     )
 
-    def _validate_value(self, value):
+    def _validate_value(self, value) -> None:
         if not isinstance(value, str) and not isinstance(value, bytes):
             raise TypeError(
                 "Values in {} must be instances of {} or {}, not {}".format(
@@ -239,7 +239,7 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
         manually_initialize_store_backend_id: str = "",
         base_public_path=None,
         store_name=None,
-    ):
+    ) -> None:
         super().__init__(
             filepath_template=filepath_template,
             filepath_prefix=filepath_prefix,
@@ -370,7 +370,7 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
 
         return key_list
 
-    def rrmdir(self, mroot, curpath):
+    def rrmdir(self, mroot, curpath) -> None:
         """
         recursively removes empty dirs between curpath and mroot inclusive
         """
@@ -455,7 +455,7 @@ class TupleS3StoreBackend(TupleStoreBackend):
         base_public_path=None,
         endpoint_url=None,
         store_name=None,
-    ):
+    ) -> None:
         super().__init__(
             filepath_template=filepath_template,
             filepath_prefix=filepath_prefix,
@@ -577,7 +577,7 @@ class TupleS3StoreBackend(TupleStoreBackend):
 
         return s3_object_key
 
-    def _move(self, source_key, dest_key, **kwargs):
+    def _move(self, source_key, dest_key, **kwargs) -> None:
         s3 = self._create_resource()
 
         source_filepath = self._convert_key_to_filepath(source_key)
@@ -648,15 +648,20 @@ class TupleS3StoreBackend(TupleStoreBackend):
         return key_list
 
     def get_url_for_key(self, key, protocol=None):
-        location = self._create_client().get_bucket_location(Bucket=self.bucket)[
-            "LocationConstraint"
-        ]
+        location = None
         if self.boto3_options.get("endpoint_url"):
             location = self.boto3_options.get("endpoint_url")
-        elif location is None:
-            location = "https://s3.amazonaws.com"
         else:
-            location = f"https://s3-{location}.amazonaws.com"
+            # build s3 endpoint when no endpoint_url is configured
+
+            location = self._create_client().get_bucket_location(Bucket=self.bucket)[
+                "LocationConstraint"
+            ]
+
+            if location is None:
+                location = "https://s3.amazonaws.com"
+            else:
+                location = f"https://s3-{location}.amazonaws.com"
 
         s3_key = self._convert_key_to_filepath(key)
 
@@ -752,7 +757,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
         public_urls=True,
         base_public_path=None,
         store_name=None,
-    ):
+    ) -> None:
         super().__init__(
             filepath_template=filepath_template,
             filepath_prefix=filepath_prefix,
@@ -852,7 +857,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
             blob.upload_from_string(value, content_type=content_type)
         return gcs_object_key
 
-    def _move(self, source_key, dest_key, **kwargs):
+    def _move(self, source_key, dest_key, **kwargs) -> None:
         from google.cloud import storage
 
         gcs = storage.Client(project=self.project)
@@ -976,7 +981,7 @@ class TupleAzureBlobStoreBackend(TupleStoreBackend):
         suppress_store_backend_id=False,
         manually_initialize_store_backend_id: str = "",
         store_name=None,
-    ):
+    ) -> None:
         super().__init__(
             filepath_template=filepath_template,
             filepath_prefix=filepath_prefix,
@@ -1079,7 +1084,7 @@ class TupleAzureBlobStoreBackend(TupleStoreBackend):
         all_keys = self.list_keys()
         return key in all_keys
 
-    def _move(self, source_key, dest_key, **kwargs):
+    def _move(self, source_key, dest_key, **kwargs) -> None:
         source_blob_path = self._convert_key_to_filepath(source_key)
         if not source_blob_path.startswith(self.prefix):
             source_blob_path = os.path.join(self.prefix, source_blob_path)
