@@ -49,7 +49,7 @@ class SubdirReaderBatchKwargsGenerator(BatchKwargsGenerator):
         reader_options=None,
         known_extensions=None,
         reader_method=None,
-    ):
+    ) -> None:
         super().__init__(name, datasource=datasource)
         if reader_options is None:
             reader_options = self._default_reader_options
@@ -257,7 +257,9 @@ class SubdirReaderBatchKwargsGenerator(BatchKwargsGenerator):
                 ),
             )
 
-    def _build_batch_kwargs_path_iter(self, path_list, reader_options=None, limit=None):
+    def _build_batch_kwargs_path_iter(
+        self, path_list, reader_options=None, limit=None
+    ) -> None:
         for path in path_list:
             yield self._build_batch_kwargs_from_path(
                 path, reader_options=reader_options, limit=limit
