@@ -145,7 +145,7 @@ class BatchFilter:
         batch_filter_parameters: Optional[IDDict] = None,
         index: Optional[Union[int, slice]] = None,
         limit: int = None,
-    ):
+    ) -> None:
         self._custom_filter_function = custom_filter_function
         self._batch_filter_parameters = batch_filter_parameters
         self._index = index
