@@ -158,7 +158,7 @@ class LegacyDatasource:
         data_asset_type=None,
         batch_kwargs_generators=None,
         **kwargs
-    ):
+    ) -> None:
         """
         Build a new datasource.
 
@@ -203,7 +203,7 @@ class LegacyDatasource:
         """
         return self._data_context
 
-    def _build_generators(self):
+    def _build_generators(self) -> None:
         """
         Build batch kwargs generator objects from the datasource configuration.
 
@@ -323,7 +323,7 @@ class LegacyDatasource:
         return batch_kwargs
 
     # TODO: move to execution engine or make a wrapper
-    def get_batch(self, batch_kwargs, batch_parameters=None):
+    def get_batch(self, batch_kwargs, batch_parameters=None) -> None:
         """Get a batch of data from the datasource.
 
         Args:
