@@ -104,10 +104,11 @@ class ExpectColumnDistinctValuesToBeInSet(ColumnExpectation):
     # This dictionary contains metadata for display in the public gallery
     library_metadata = {
         "maturity": "production",
-        "package": "great_expectations",
         "tags": ["core expectation", "column aggregate expectation"],
         "contributors": ["@great_expectations"],
         "requirements": [],
+        "has_full_test_suite": True,
+        "manually_reviewed_code": True,
     }
 
     # Setting necessary computation metric dependencies and defining kwargs, as well as assigning kwargs default values\
@@ -359,7 +360,7 @@ class ExpectColumnDistinctValuesToBeInSet(ColumnExpectation):
 
     def validate_configuration(
         self, configuration: Optional[ExpectationConfiguration]
-    ) -> bool:
+    ) -> None:
         """Validating that user has inputted a value set and that configuration has been initialized"""
         super().validate_configuration(configuration)
 
@@ -375,7 +376,6 @@ class ExpectColumnDistinctValuesToBeInSet(ColumnExpectation):
                 ), 'Evaluation Parameter dict for value_set kwarg must have "$PARAMETER" key'
         except AssertionError as e:
             raise InvalidExpectationConfigurationError(str(e))
-        return True
 
     def _validate(
         self,
