@@ -52,12 +52,13 @@ class ExpectTableRowCountToEqual(TableExpectation):
 
     library_metadata = {
         "maturity": "production",
-        "package": "great_expectations",
         "tags": ["core expectation", "table expectation"],
         "contributors": [
             "@great_expectations",
         ],
         "requirements": [],
+        "has_full_test_suite": True,
+        "manually_reviewed_code": True,
     }
 
     metric_dependencies = ("table.row_count",)
@@ -73,7 +74,7 @@ class ExpectTableRowCountToEqual(TableExpectation):
 
     def validate_configuration(
         self, configuration: Optional[ExpectationConfiguration]
-    ) -> bool:
+    ) -> None:
         """
         Validates that a configuration has been set, and sets a configuration if it has yet to be set. Ensures that
         necessary configuration arguments have been provided for the validation of the expectation.
@@ -82,7 +83,7 @@ class ExpectTableRowCountToEqual(TableExpectation):
             configuration (OPTIONAL[ExpectationConfiguration]): \
                 An optional Expectation Configuration entry that will be used to configure the expectation
         Returns:
-            True if the configuration has been validated successfully. Otherwise, raises an exception
+            None. Raises InvalidExpectationConfigurationError if the config is not validated successfully
         """
 
         # Setting up a configuration
@@ -103,8 +104,6 @@ class ExpectTableRowCountToEqual(TableExpectation):
         except AssertionError as e:
             raise InvalidExpectationConfigurationError(str(e))
 
-        return True
-
     @classmethod
     def _atomic_prescriptive_template(
         cls,
