@@ -1,6 +1,6 @@
 import json
 import logging
-from typing import Any, Dict, List, Optional, Type, Union
+from typing import Any, Dict, List, Optional, Type
 
 from ruamel.yaml.comments import CommentedMap
 
@@ -9,6 +9,7 @@ from great_expectations.data_context.types.base import BaseYamlConfig
 from great_expectations.marshmallow__shade import (
     INCLUDE,
     Schema,
+    ValidationError,
     fields,
     post_dump,
     post_load,
@@ -101,19 +102,16 @@ class NotNullSchema(Schema):
         return cleaned_output
 
 
-class DomainBuilderConfig(DictDot):
+class DomainBuilderConfig(SerializableDictDot):
     def __init__(
         self,
         class_name: str,
         module_name: Optional[str] = None,
-        batch_request: Optional[Union[dict, str]] = None,
         **kwargs,
-    ):
+    ) -> None:
         self.module_name = module_name
         self.class_name = class_name
 
-        self.batch_request = batch_request
-
         for k, v in kwargs.items():
             setattr(self, k, v)
             logger.debug(
@@ -123,6 +121,49 @@ class DomainBuilderConfig(DictDot):
                 self.__class__.__name__,
             )
 
+    def to_json_dict(self) -> dict:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of "SerializableDictDot.to_json_dict() occurs frequently and should ideally serve as the
+        reference implementation in the "SerializableDictDot" class itself.  However, the circular import dependencies,
+        due to the location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules
+        make this refactoring infeasible at the present time.
+        """
+        dict_obj: dict = self.to_dict()
+        serializeable_dict: dict = convert_to_json_serializable(data=dict_obj)
+        return serializeable_dict
+
+    def __repr__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__repr__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        json_dict: dict = self.to_json_dict()
+        deep_filter_properties_iterable(
+            properties=json_dict,
+            inplace=True,
+        )
+
+        keys: List[str] = sorted(list(json_dict.keys()))
+
+        key: str
+        sorted_json_dict: dict = {key: json_dict[key] for key in keys}
+
+        return json.dumps(sorted_json_dict, indent=2)
+
+    def __str__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__str__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        return self.__repr__()
+
 
 class DomainBuilderConfigSchema(NotNullSchema):
     class Meta:
@@ -139,13 +180,9 @@ class DomainBuilderConfigSchema(NotNullSchema):
         required=True,
         allow_none=False,
     )
-    batch_request = fields.Raw(
-        required=False,
-        allow_none=True,
-    )
 
 
-class ParameterBuilderConfig(DictDot):
+class ParameterBuilderConfig(SerializableDictDot):
     def __init__(
         self,
         name: str,
@@ -153,9 +190,8 @@ class ParameterBuilderConfig(DictDot):
         module_name: Optional[str] = None,
         evaluation_parameter_builder_configs: Optional[list] = None,
         json_serialize: bool = True,
-        batch_request: Optional[Union[dict, str]] = None,
         **kwargs,
-    ):
+    ) -> None:
         self.module_name = module_name
         self.class_name = class_name
 
@@ -165,8 +201,6 @@ class ParameterBuilderConfig(DictDot):
 
         self.json_serialize = json_serialize
 
-        self.batch_request = batch_request
-
         for k, v in kwargs.items():
             setattr(self, k, v)
             logger.debug(
@@ -176,6 +210,49 @@ class ParameterBuilderConfig(DictDot):
                 self.__class__.__name__,
             )
 
+    def to_json_dict(self) -> dict:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of "SerializableDictDot.to_json_dict() occurs frequently and should ideally serve as the
+        reference implementation in the "SerializableDictDot" class itself.  However, the circular import dependencies,
+        due to the location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules
+        make this refactoring infeasible at the present time.
+        """
+        dict_obj: dict = self.to_dict()
+        serializeable_dict: dict = convert_to_json_serializable(data=dict_obj)
+        return serializeable_dict
+
+    def __repr__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__repr__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        json_dict: dict = self.to_json_dict()
+        deep_filter_properties_iterable(
+            properties=json_dict,
+            inplace=True,
+        )
+
+        keys: List[str] = sorted(list(json_dict.keys()))
+
+        key: str
+        sorted_json_dict: dict = {key: json_dict[key] for key in keys}
+
+        return json.dumps(sorted_json_dict, indent=2)
+
+    def __str__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__str__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        return self.__repr__()
+
 
 class ParameterBuilderConfigSchema(NotNullSchema):
     class Meta:
@@ -210,13 +287,9 @@ class ParameterBuilderConfigSchema(NotNullSchema):
         allow_none=True,
         missing=True,
     )
-    batch_request = fields.Raw(
-        required=False,
-        allow_none=True,
-    )
 
 
-class ExpectationConfigurationBuilderConfig(DictDot):
+class ExpectationConfigurationBuilderConfig(SerializableDictDot):
     def __init__(
         self,
         expectation_type: str,
@@ -224,9 +297,8 @@ class ExpectationConfigurationBuilderConfig(DictDot):
         module_name: Optional[str] = None,
         meta: Optional[dict] = None,
         validation_parameter_builder_configs: Optional[list] = None,
-        batch_request: Optional[Union[dict, str]] = None,
         **kwargs,
-    ):
+    ) -> None:
         self.module_name = module_name
         self.class_name = class_name
 
@@ -236,8 +308,6 @@ class ExpectationConfigurationBuilderConfig(DictDot):
 
         self.validation_parameter_builder_configs = validation_parameter_builder_configs
 
-        self.batch_request = batch_request
-
         for k, v in kwargs.items():
             setattr(self, k, v)
             logger.debug(
@@ -247,6 +317,49 @@ class ExpectationConfigurationBuilderConfig(DictDot):
                 self.__class__.__name__,
             )
 
+    def to_json_dict(self) -> dict:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of "SerializableDictDot.to_json_dict() occurs frequently and should ideally serve as the
+        reference implementation in the "SerializableDictDot" class itself.  However, the circular import dependencies,
+        due to the location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules
+        make this refactoring infeasible at the present time.
+        """
+        dict_obj: dict = self.to_dict()
+        serializeable_dict: dict = convert_to_json_serializable(data=dict_obj)
+        return serializeable_dict
+
+    def __repr__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__repr__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        json_dict: dict = self.to_json_dict()
+        deep_filter_properties_iterable(
+            properties=json_dict,
+            inplace=True,
+        )
+
+        keys: List[str] = sorted(list(json_dict.keys()))
+
+        key: str
+        sorted_json_dict: dict = {key: json_dict[key] for key in keys}
+
+        return json.dumps(sorted_json_dict, indent=2)
+
+    def __str__(self) -> str:
+        """
+        # TODO: <Alex>2/4/2022</Alex>
+        This implementation of a custom "__str__()" occurs frequently and should ideally serve as the reference
+        implementation in the "SerializableDictDot" class.  However, the circular import dependencies, due to the
+        location of the "great_expectations/types/__init__.py" and "great_expectations/core/util.py" modules make this
+        refactoring infeasible at the present time.
+        """
+        return self.__repr__()
+
 
 class ExpectationConfigurationBuilderConfigSchema(NotNullSchema):
     class Meta:
@@ -286,21 +399,19 @@ class ExpectationConfigurationBuilderConfigSchema(NotNullSchema):
         required=False,
         allow_none=True,
     )
-    batch_request = fields.Raw(
-        required=False,
-        allow_none=True,
-    )
 
 
 class RuleConfig(SerializableDictDot):
     def __init__(
         self,
-        expectation_configuration_builders: List[
-            dict
-        ],  # see ExpectationConfigurationBuilderConfig
+        variables: Optional[Dict[str, Any]] = None,
         domain_builder: Optional[dict] = None,  # see DomainBuilderConfig
         parameter_builders: Optional[List[dict]] = None,  # see ParameterBuilderConfig
-    ):
+        expectation_configuration_builders: Optional[
+            List[dict]
+        ] = None,  # see ExpectationConfigurationBuilderConfig
+    ) -> None:
+        self.variables = variables
         self.domain_builder = domain_builder
         self.parameter_builders = parameter_builders
         self.expectation_configuration_builders = expectation_configuration_builders
@@ -355,6 +466,14 @@ class RuleConfigSchema(NotNullSchema):
 
     __config_class__ = RuleConfig
 
+    variables = fields.Dict(
+        keys=fields.String(
+            required=True,
+            allow_none=False,
+        ),
+        required=False,
+        allow_none=True,
+    )
     domain_builder = fields.Nested(
         DomainBuilderConfigSchema,
         required=False,
@@ -375,8 +494,8 @@ class RuleConfigSchema(NotNullSchema):
             required=True,
             allow_none=False,
         ),
-        required=True,
-        allow_none=False,
+        required=False,
+        allow_none=True,
     )
 
 
@@ -386,13 +505,11 @@ class RuleBasedProfilerConfig(BaseYamlConfig):
         name: str,
         config_version: float,
         rules: Dict[str, dict],  # see RuleConfig
-        class_name: Optional[str] = None,
-        module_name: Optional[str] = None,
         variables: Optional[Dict[str, Any]] = None,
         commented_map: Optional[CommentedMap] = None,
-    ):
-        self.module_name = module_name
-        self.class_name = class_name
+    ) -> None:
+        self.module_name = "great_expectations.rule_based_profiler"
+        self.class_name = "RuleBasedProfiler"
 
         self.name = name
 
@@ -411,6 +528,25 @@ class RuleBasedProfilerConfig(BaseYamlConfig):
     def get_schema_class(cls) -> Type["RuleBasedProfilerConfigSchema"]:  # noqa: F821
         return RuleBasedProfilerConfigSchema
 
+    @classmethod
+    def from_commented_map(
+        cls, commented_map: CommentedMap
+    ) -> "RuleBasedProfilerConfig":
+        """Override parent implementation to pop unnecessary attrs from config.
+
+        Please see parent BaseYamlConfig for more details.
+        """
+        try:
+            config: dict = cls._get_schema_instance().load(commented_map)
+            config.pop("class_name", None)
+            config.pop("module_name", None)
+            return cls.get_config_class()(commented_map=commented_map, **config)
+        except ValidationError:
+            logger.error(
+                "Encountered errors during loading config.  See ValidationError for more details."
+            )
+            raise
+
     def to_json_dict(self) -> dict:
         """
         # TODO: <Alex>2/4/2022</Alex>
@@ -501,8 +637,6 @@ class RuleBasedProfilerConfig(BaseYamlConfig):
         }
 
         return cls(
-            class_name=profiler.__class__.__name__,
-            module_name=profiler.__class__.__module__,
             name=profiler.config.name,
             config_version=profiler.config.config_version,
             variables=runtime_variables,
