@@ -16,8 +16,8 @@ from pyparsing import (
 )
 
 import great_expectations.exceptions as ge_exceptions
-from great_expectations.core.batch import Batch, BatchRequest, RuntimeBatchRequest
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.rule_based_profiler.config import ParameterBuilderConfig
 from great_expectations.rule_based_profiler.expectation_configuration_builder import (
     ExpectationConfigurationBuilder,
 )
@@ -67,34 +67,28 @@ class DefaultExpectationConfigurationBuilder(ExpectationConfigurationBuilder):
         expectation_type: str,
         meta: Optional[Dict[str, Any]] = None,
         condition: Optional[str] = None,
-        validation_parameter_builder_configs: Optional[List[dict]] = None,
-        batch_list: Optional[List[Batch]] = None,
-        batch_request: Optional[
-            Union[str, BatchRequest, RuntimeBatchRequest, dict]
+        validation_parameter_builder_configs: Optional[
+            List[ParameterBuilderConfig]
         ] = None,
-        data_context: Optional["DataContext"] = None,  # noqa: F821
+        data_context: Optional["BaseDataContext"] = None,  # noqa: F821
         **kwargs,
-    ):
+    ) -> None:
         """
         Args:
             expectation_type: the "expectation_type" argument of "ExpectationConfiguration" object to be emitted.
-            meta: the "meta" argument of "ExpectationConfiguration" object to be emitted.
+            meta: the "meta" argument of "ExpectationConfiguration" object to be emitted
             condition: Boolean statement (expressed as string and following specified grammar), which controls whether
-            or not underlying logic should be executed and thus resulting "ExpectationConfiguration" emitted.
+            or not underlying logic should be executed and thus resulting "ExpectationConfiguration" emitted
             validation_parameter_builder_configs: ParameterBuilder configurations, having whose outputs available (as
-            fully-qualified parameter names) is pre-requisite for present ExpectationConfigurationBuilder instance.
-            These "ParameterBuilder" configurations help build kwargs needed for this "ExpectationConfigurationBuilder".
-            batch_list: explicitly passed Batch objects for parameter computation (take precedence over batch_request).
-            batch_request: specified in ParameterBuilder configuration to get Batch objects for parameter computation.
-            data_context: DataContext
+            fully-qualified parameter names) is pre-requisite for present ExpectationConfigurationBuilder instance
+            These "ParameterBuilder" configurations help build kwargs needed for this "ExpectationConfigurationBuilder"
+            data_context: BaseDataContext associated with this ExpectationConfigurationBuilder
             kwargs: additional arguments
         """
 
         super().__init__(
             expectation_type=expectation_type,
             validation_parameter_builder_configs=validation_parameter_builder_configs,
-            batch_list=batch_list,
-            batch_request=batch_request,
             data_context=data_context,
             **kwargs,
         )
@@ -120,6 +114,10 @@ class DefaultExpectationConfigurationBuilder(ExpectationConfigurationBuilder):
 
         self._condition = condition
 
+        self._validation_parameter_builder_configs = (
+            validation_parameter_builder_configs
+        )
+
         self._kwargs = kwargs
 
     @property
@@ -130,6 +128,12 @@ class DefaultExpectationConfigurationBuilder(ExpectationConfigurationBuilder):
     def condition(self) -> Optional[str]:
         return self._condition
 
+    @property
+    def validation_parameter_builder_configs(
+        self,
+    ) -> Optional[List[ParameterBuilderConfig]]:
+        return self._validation_parameter_builder_configs
+
     @property
     def kwargs(self) -> dict:
         return self._kwargs
