@@ -3,25 +3,45 @@ import enum
 from dataclasses import dataclass
 from typing import Optional, Tuple, Union
 
+from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.exceptions import ProfilerConfigurationError
+from great_expectations.types import SerializableDictDot
 
 
-@dataclass
-class CardinalityLimit(abc.ABC):
+@dataclass(frozen=True)
+class CardinalityLimit(abc.ABC, SerializableDictDot):
     name: str
 
 
-@dataclass
+@dataclass(frozen=True)
 class RelativeCardinalityLimit(CardinalityLimit):
     max_proportion_unique: float
     metric_name_defining_limit: str = "column.unique_proportion"
 
+    def to_json_dict(self) -> dict:
+        return convert_to_json_serializable(
+            {
+                "name": self.name,
+                "max_proportion_unique": self.max_proportion_unique,
+                "metric_name_defining_limit": self.metric_name_defining_limit,
+            }
+        )
 
-@dataclass
+
+@dataclass(frozen=True)
 class AbsoluteCardinalityLimit(CardinalityLimit):
     max_unique_values: int
     metric_name_defining_limit: str = "column.distinct_values.count"
 
+    def to_json_dict(self) -> dict:
+        return convert_to_json_serializable(
+            {
+                "name": self.name,
+                "max_proportion_unique": self.max_unique_values,
+                "metric_name_defining_limit": self.metric_name_defining_limit,
+            }
+        )
+
 
 class CardinalityLimitMode(enum.Enum):
     """Preset limits based on unique values (cardinality)
@@ -97,7 +117,7 @@ class CardinalityChecker:
         limit_mode: Optional[Union[CardinalityLimitMode, str]] = None,
         max_unique_values: Optional[int] = None,
         max_proportion_unique: Optional[float] = None,
-    ):
+    ) -> None:
         self._limit_mode = self._convert_to_cardinality_mode(
             limit_mode=limit_mode,
             max_unique_values=max_unique_values,
@@ -119,7 +139,7 @@ class CardinalityChecker:
                 of unique values.
 
         Returns:
-            boolean of whether the cardinality is within the configured limit
+            Boolean of whether the cardinality is within the configured limit
         """
         self._validate_metric_value(metric_value=metric_value)
         if isinstance(self._limit_mode, AbsoluteCardinalityLimit):
