@@ -9,6 +9,9 @@ from great_expectations.rule_based_profiler.parameter_builder.parameter_builder
 from great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder import (  # isort:skip
     MetricMultiBatchParameterBuilder,
 )
+from great_expectations.rule_based_profiler.parameter_builder.metric_single_batch_parameter_builder import (  # isort:skip
+    MetricSingleBatchParameterBuilder,
+)
 from great_expectations.rule_based_profiler.parameter_builder.numeric_metric_range_multi_batch_parameter_builder import (  # isort:skip
     NumericMetricRangeMultiBatchParameterBuilder,
 )
@@ -24,3 +27,6 @@ from great_expectations.rule_based_profiler.parameter_builder.simple_date_format
 from great_expectations.rule_based_profiler.parameter_builder.value_set_multi_batch_parameter_builder import (  # isort:skip
     ValueSetMultiBatchParameterBuilder,
 )
+from great_expectations.rule_based_profiler.parameter_builder.partition_parameter_builder import (  # isort:skip
+    PartitionParameterBuilder,
+)
