@@ -1,21 +1,24 @@
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Dict, List, Optional, Union
 
-from great_expectations.core.batch import Batch, BatchRequest, RuntimeBatchRequest
+import numpy as np
+
+from great_expectations.rule_based_profiler.config import ParameterBuilderConfig
 from great_expectations.rule_based_profiler.helpers.util import (
     get_parameter_value_and_validate_return_type,
 )
 from great_expectations.rule_based_profiler.parameter_builder import (
-    AttributedResolvedMetrics,
     MetricComputationDetails,
     MetricComputationResult,
-    MetricValues,
     ParameterBuilder,
 )
 from great_expectations.rule_based_profiler.types import (
-    PARAMETER_KEY,
+    FULLY_QUALIFIED_PARAMETER_NAME_ATTRIBUTED_VALUE_KEY,
+    FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY,
+    FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY,
     Domain,
     ParameterContainer,
 )
+from great_expectations.types.attributes import Attributes
 
 
 class MetricMultiBatchParameterBuilder(ParameterBuilder):
@@ -27,20 +30,18 @@ class MetricMultiBatchParameterBuilder(ParameterBuilder):
     def __init__(
         self,
         name: str,
-        metric_name: str,
+        metric_name: Optional[str] = None,
         metric_domain_kwargs: Optional[Union[str, dict]] = None,
         metric_value_kwargs: Optional[Union[str, dict]] = None,
         enforce_numeric_metric: Union[str, bool] = False,
         replace_nan_with_zero: Union[str, bool] = False,
         reduce_scalar_metric: Union[str, bool] = True,
-        evaluation_parameter_builder_configs: Optional[List[dict]] = None,
-        json_serialize: Union[str, bool] = True,
-        batch_list: Optional[List[Batch]] = None,
-        batch_request: Optional[
-            Union[str, BatchRequest, RuntimeBatchRequest, dict]
+        evaluation_parameter_builder_configs: Optional[
+            List[ParameterBuilderConfig]
         ] = None,
-        data_context: Optional["DataContext"] = None,  # noqa: F821
-    ):
+        json_serialize: Union[str, bool] = True,
+        data_context: Optional["BaseDataContext"] = None,  # noqa: F821
+    ) -> None:
         """
         Args:
             name: the name of this parameter -- this is user-specified parameter name (from configuration);
@@ -57,16 +58,12 @@ class MetricMultiBatchParameterBuilder(ParameterBuilder):
             ParameterBuilder objects' outputs available (as fully-qualified parameter names) is pre-requisite.
             These "ParameterBuilder" configurations help build parameters needed for this "ParameterBuilder".
             json_serialize: If True (default), convert computed value to JSON prior to saving results.
-            batch_list: explicitly passed Batch objects for parameter computation (take precedence over batch_request).
-            batch_request: specified in ParameterBuilder configuration to get Batch objects for parameter computation.
-            data_context: DataContext
+            data_context: BaseDataContext associated with this ParameterBuilder
         """
         super().__init__(
             name=name,
             evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
             json_serialize=json_serialize,
-            batch_list=batch_list,
-            batch_request=batch_request,
             data_context=data_context,
         )
 
@@ -79,18 +76,14 @@ class MetricMultiBatchParameterBuilder(ParameterBuilder):
 
         self._reduce_scalar_metric = reduce_scalar_metric
 
-    @property
-    def fully_qualified_parameter_name(self) -> str:
-        return f"{PARAMETER_KEY}{self.name}"
-
-    """
-    Full getter/setter accessors for needed properties are for configuring MetricMultiBatchParameterBuilder dynamically.
-    """
-
     @property
     def metric_name(self) -> str:
         return self._metric_name
 
+    @metric_name.setter
+    def metric_name(self, value: str) -> None:
+        self._metric_name = value
+
     @property
     def metric_domain_kwargs(self) -> Optional[Union[str, dict]]:
         return self._metric_domain_kwargs
@@ -117,16 +110,16 @@ class MetricMultiBatchParameterBuilder(ParameterBuilder):
 
     def _build_parameters(
         self,
-        parameter_container: ParameterContainer,
         domain: Domain,
         variables: Optional[ParameterContainer] = None,
         parameters: Optional[Dict[str, ParameterContainer]] = None,
-    ) -> Tuple[Any, dict]:
+        recompute_existing_parameter_values: bool = False,
+    ) -> Attributes:
         """
-        Builds ParameterContainer object that holds ParameterNode objects with attribute name-value pairs and optional
-        details.
+        Builds ParameterContainer object that holds ParameterNode objects with attribute name-value pairs and details.
 
-        return: Tuple containing computed_parameter_value and parameter_computation_details metadata.
+        Returns:
+            Attributes object, containing computed parameter values and parameter computation details metadata.
         """
         metric_computation_result: MetricComputationResult = self.get_metrics(
             metric_name=self.metric_name,
@@ -138,7 +131,6 @@ class MetricMultiBatchParameterBuilder(ParameterBuilder):
             variables=variables,
             parameters=parameters,
         )
-        metric_values: MetricValues = metric_computation_result.metric_values
         details: MetricComputationDetails = metric_computation_result.details
 
         # Obtain reduce_scalar_metric from "rule state" (i.e., variables and parameters); from instance variable otherwise.
@@ -150,17 +142,51 @@ class MetricMultiBatchParameterBuilder(ParameterBuilder):
             parameters=parameters,
         )
 
-        # As a simplification, apply reduction to scalar in case of one-dimensional metric (for convenience).
-        if (
-            reduce_scalar_metric
-            and isinstance(metric_values, list)
-            and len(metric_values) == 1
-            and isinstance(metric_values[0], AttributedResolvedMetrics)
-            and metric_values[0].metric_values.shape[1] == 1
-        ):
-            metric_values = metric_values[0].metric_values[:, 0]
+        if len(metric_computation_result.attributed_resolved_metrics) == 1:
+            # As a simplification, apply reduction to scalar in case of one-dimensional metric (for convenience).
+            if (
+                reduce_scalar_metric
+                and isinstance(
+                    metric_computation_result.attributed_resolved_metrics[
+                        0
+                    ].metric_values,
+                    np.ndarray,
+                )
+                and metric_computation_result.attributed_resolved_metrics[
+                    0
+                ].metric_values.shape[1]
+                == 1
+            ):
+                return Attributes(
+                    {
+                        FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY: metric_computation_result.attributed_resolved_metrics[
+                            0
+                        ].metric_values[
+                            :, 0
+                        ],
+                        FULLY_QUALIFIED_PARAMETER_NAME_ATTRIBUTED_VALUE_KEY: metric_computation_result.attributed_resolved_metrics[
+                            0
+                        ].attributed_metric_values,
+                        FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY: details,
+                    }
+                )
 
-        return (
-            metric_values,
-            details,
+            return Attributes(
+                {
+                    FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY: metric_computation_result.attributed_resolved_metrics[
+                        0
+                    ].metric_values,
+                    FULLY_QUALIFIED_PARAMETER_NAME_ATTRIBUTED_VALUE_KEY: metric_computation_result.attributed_resolved_metrics[
+                        0
+                    ].attributed_metric_values,
+                    FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY: details,
+                }
+            )
+
+        return Attributes(
+            {
+                FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY: metric_computation_result.attributed_resolved_metrics,
+                FULLY_QUALIFIED_PARAMETER_NAME_ATTRIBUTED_VALUE_KEY: metric_computation_result.attributed_resolved_metrics,
+                FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY: details,
+            }
         )
