@@ -1,13 +1,16 @@
 import copy
 import itertools
+import logging
 from abc import ABC, abstractmethod
+from collections import OrderedDict
 from dataclasses import asdict, dataclass, make_dataclass
-from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union, cast
 
 import numpy as np
+import pandas as pd
 
 import great_expectations.exceptions as ge_exceptions
-from great_expectations.core.batch import Batch, BatchRequest, RuntimeBatchRequest
+from great_expectations.core.batch import Batch, BatchRequestBase
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.rule_based_profiler.config import ParameterBuilderConfig
@@ -25,7 +28,6 @@ from great_expectations.rule_based_profiler.helpers.util import (
 )
 from great_expectations.rule_based_profiler.types import (
     PARAMETER_KEY,
-    Attributes,
     Builder,
     Domain,
     ParameterContainer,
@@ -33,14 +35,18 @@ from great_expectations.rule_based_profiler.types import (
     get_fully_qualified_parameter_names,
 )
 from great_expectations.types import SerializableDictDot
+from great_expectations.types.attributes import Attributes
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
+
 # TODO: <Alex>These are placeholder types, until a formal metric computation state class is made available.</Alex>
-MetricValue = Union[Any, List[Any], np.ndarray]
-MetricValues = Union[MetricValue, np.ndarray]
+MetricValue = Union[Any, List[Any], pd.DataFrame, pd.Series, np.ndarray]
+MetricValues = Union[MetricValue, pd.DataFrame, pd.Series, np.ndarray]
 MetricComputationDetails = Dict[str, Any]
 MetricComputationResult = make_dataclass(
-    "MetricComputationResult", ["metric_values", "details"]
+    "MetricComputationResult", ["attributed_resolved_metrics", "details"]
 )
 
 
@@ -53,19 +59,47 @@ class AttributedResolvedMetrics(SerializableDictDot):
     with uniquely identifiable attribution object so that receivers can filter them from overall resolved metrics.
     """
 
-    metric_values: MetricValues
-    metric_attributes: Attributes
+    metric_attributes: Optional[Attributes] = None
+    metric_values_by_batch_id: Optional[Dict[str, MetricValue]] = None
 
-    def add_resolved_metric(self, value: Any) -> None:
-        if self.metric_values is None:
-            self.metric_values = []
+    @staticmethod
+    def get_metric_values_from_attributed_metric_values(
+        attributed_metric_values: Dict[str, MetricValue]
+    ) -> MetricValues:
+        if attributed_metric_values is None:
+            return None
 
-        self.metric_values.append(value)
+        values: MetricValues = list(attributed_metric_values.values())[0]
+        if values is not None and isinstance(values, (pd.DataFrame, pd.Series)):
+            return list(attributed_metric_values.values())
+
+        return np.array(list(attributed_metric_values.values()))
+
+    def add_resolved_metric(self, batch_id: str, value: MetricValue) -> None:
+        if self.metric_values_by_batch_id is None:
+            self.metric_values_by_batch_id = {}
+
+        if not isinstance(self.metric_values_by_batch_id, OrderedDict):
+            self.metric_values_by_batch_id = OrderedDict(self.metric_values_by_batch_id)
+
+        self.metric_values_by_batch_id[batch_id] = value
 
     @property
     def id(self) -> str:
         return self.metric_attributes.to_id()
 
+    @property
+    def attributed_metric_values(self) -> Optional[Dict[str, MetricValue]]:
+        return self.metric_values_by_batch_id
+
+    @property
+    def metric_values(self) -> MetricValues:
+        return (
+            AttributedResolvedMetrics.get_metric_values_from_attributed_metric_values(
+                attributed_metric_values=self.attributed_metric_values
+            )
+        )
+
     def to_dict(self) -> dict:
         return asdict(self)
 
@@ -73,7 +107,7 @@ class AttributedResolvedMetrics(SerializableDictDot):
         return convert_to_json_serializable(data=self.to_dict())
 
 
-class ParameterBuilder(Builder, ABC):
+class ParameterBuilder(ABC, Builder):
     """
     A ParameterBuilder implementation provides support for building Expectation Configuration Parameters suitable for
     use in other ParameterBuilders or in ConfigurationBuilders as part of profiling.
@@ -102,12 +136,8 @@ class ParameterBuilder(Builder, ABC):
             List[ParameterBuilderConfig]
         ] = None,
         json_serialize: Union[str, bool] = True,
-        batch_list: Optional[List[Batch]] = None,
-        batch_request: Optional[
-            Union[str, BatchRequest, RuntimeBatchRequest, dict]
-        ] = None,
-        data_context: Optional["DataContext"] = None,  # noqa: F821
-    ):
+        data_context: Optional["BaseDataContext"] = None,  # noqa: F821
+    ) -> None:
         """
         The ParameterBuilder will build ParameterNode objects for a Domain from the Rule.
 
@@ -119,18 +149,16 @@ class ParameterBuilder(Builder, ABC):
             ParameterBuilder objects' outputs available (as fully-qualified parameter names) is pre-requisite.
             These "ParameterBuilder" configurations help build parameters needed for this "ParameterBuilder".
             json_serialize: If True (default), convert computed value to JSON prior to saving results.
-            batch_list: explicitly passed Batch objects for parameter computation (take precedence over batch_request).
-            batch_request: specified in ParameterBuilder configuration to get Batch objects for parameter computation.
-            data_context: DataContext
+            data_context: BaseDataContext associated with ParameterBuilder
         """
-        super().__init__(
-            batch_list=batch_list,
-            batch_request=batch_request,
-            data_context=data_context,
-        )
+        super().__init__(data_context=data_context)
 
         self._name = name
 
+        self._evaluation_parameter_builder_configs = (
+            evaluation_parameter_builder_configs
+        )
+
         self._evaluation_parameter_builders = init_rule_parameter_builders(
             parameter_builder_configs=evaluation_parameter_builder_configs,
             data_context=self._data_context,
@@ -140,63 +168,84 @@ class ParameterBuilder(Builder, ABC):
 
     def build_parameters(
         self,
-        parameter_container: ParameterContainer,
         domain: Domain,
         variables: Optional[ParameterContainer] = None,
         parameters: Optional[Dict[str, ParameterContainer]] = None,
         parameter_computation_impl: Optional[Callable] = None,
         json_serialize: Optional[bool] = None,
+        batch_list: Optional[List[Batch]] = None,
+        batch_request: Optional[Union[BatchRequestBase, dict]] = None,
+        recompute_existing_parameter_values: bool = False,
     ) -> None:
-        resolve_evaluation_dependencies(
-            parameter_builder=self,
-            parameter_container=parameter_container,
+        """
+        Args:
+            domain: Domain object that is context for execution of this ParameterBuilder object.
+            variables: attribute name/value pairs
+            parameters: Dictionary of ParameterContainer objects corresponding to all Domain objects in memory.
+            parameter_computation_impl: Object containing desired ParameterBuilder implementation.
+            json_serialize: If absent, use property value (in standard way, supporting variables look-up).
+            batch_list: Explicit list of Batch objects to supply data at runtime.
+            batch_request: Explicit batch_request used to supply data at runtime.
+            recompute_existing_parameter_values: If "True", recompute value if "fully_qualified_parameter_name" exists.
+        """
+        fully_qualified_parameter_names: List[
+            str
+        ] = get_fully_qualified_parameter_names(
             domain=domain,
             variables=variables,
             parameters=parameters,
         )
-
-        if parameter_computation_impl is None:
-            parameter_computation_impl = self._build_parameters
-
-        computed_parameter_value: Any
-        parameter_computation_details: dict
-        (
-            computed_parameter_value,
-            parameter_computation_details,
-        ) = parameter_computation_impl(
-            parameter_container=parameter_container,
-            domain=domain,
-            variables=variables,
-            parameters=parameters,
-        )
-
-        if json_serialize is None:
-            # Obtain json_serialize directive from "rule state" (i.e., variables and parameters); from instance variable otherwise.
-            json_serialize = get_parameter_value_and_validate_return_type(
-                domain=domain,
-                parameter_reference=self.json_serialize,
-                expected_return_type=bool,
-                variables=variables,
-                parameters=parameters,
+        if (
+            recompute_existing_parameter_values
+            or self.fully_qualified_parameter_name
+            not in fully_qualified_parameter_names
+        ):
+            self.set_batch_list_or_batch_request(
+                batch_list=batch_list,
+                batch_request=batch_request,
             )
 
-        parameter_values: Dict[str, Any] = {
-            self.fully_qualified_parameter_name: {
-                "value": convert_to_json_serializable(data=computed_parameter_value)
+            resolve_evaluation_dependencies(
+                parameter_builder=self,
+                domain=domain,
+                variables=variables,
+                parameters=parameters,
+                fully_qualified_parameter_names=fully_qualified_parameter_names,
+                recompute_existing_parameter_values=recompute_existing_parameter_values,
+            )
+
+            if parameter_computation_impl is None:
+                parameter_computation_impl = self._build_parameters
+
+            parameter_computation_result: Attributes = parameter_computation_impl(
+                domain=domain,
+                variables=variables,
+                parameters=parameters,
+                recompute_existing_parameter_values=recompute_existing_parameter_values,
+            )
+
+            if json_serialize is None:
+                # Obtain json_serialize directive from "rule state" (i.e., variables and parameters); from instance variable otherwise.
+                json_serialize = get_parameter_value_and_validate_return_type(
+                    domain=domain,
+                    parameter_reference=self.json_serialize,
+                    expected_return_type=bool,
+                    variables=variables,
+                    parameters=parameters,
+                )
+
+            parameter_values: Dict[str, Any] = {
+                self.fully_qualified_parameter_name: convert_to_json_serializable(
+                    data=parameter_computation_result
+                )
                 if json_serialize
-                else computed_parameter_value,
-                "details": parameter_computation_details,
-            },
-        }
+                else parameter_computation_result,
+            }
 
-        build_parameter_container(
-            parameter_container=parameter_container, parameter_values=parameter_values
-        )
-
-    @property
-    @abstractmethod
-    def fully_qualified_parameter_name(self) -> str:
-        pass
+            build_parameter_container(
+                parameter_container=parameters[domain.id],
+                parameter_values=parameter_values,
+            )
 
     @property
     def name(self) -> str:
@@ -208,23 +257,33 @@ class ParameterBuilder(Builder, ABC):
     ) -> Optional[List["ParameterBuilder"]]:  # noqa: F821
         return self._evaluation_parameter_builders
 
+    @property
+    def evaluation_parameter_builder_configs(
+        self,
+    ) -> Optional[List[ParameterBuilderConfig]]:
+        return self._evaluation_parameter_builder_configs
+
     @property
     def json_serialize(self) -> Union[str, bool]:
         return self._json_serialize
 
+    @property
+    def fully_qualified_parameter_name(self) -> str:
+        return f"{PARAMETER_KEY}{self.name}"
+
     @abstractmethod
     def _build_parameters(
         self,
-        parameter_container: ParameterContainer,
         domain: Domain,
         variables: Optional[ParameterContainer] = None,
         parameters: Optional[Dict[str, ParameterContainer]] = None,
-    ) -> Tuple[Any, dict]:
+        recompute_existing_parameter_values: bool = False,
+    ) -> Attributes:
         """
-        Builds ParameterContainer object that holds ParameterNode objects with attribute name-value pairs and optional
-        details.
+        Builds ParameterContainer object that holds ParameterNode objects with attribute name-value pairs and details.
 
-        return: Tuple containing computed_parameter_value and parameter_computation_details metadata.
+        Returns:
+            Attributes object, containing computed parameter values and parameter computation details metadata.
         """
         pass
 
@@ -291,6 +350,12 @@ class ParameterBuilder(Builder, ABC):
         significant dimension) is the number of measurements (e.g., one per Batch of data), while "R^m" is the
         multi-dimensional metric, whose values are being estimated, and details (to be used for metadata purposes).
         """
+        if not metric_name:
+            raise ge_exceptions.ProfilerExecutionError(
+                message=f"""Utilizing "{self.__class__.__name__}.get_metrics()" requires valid "metric_name" to be \
+specified (empty "metric_name" value detected)."""
+            )
+
         batch_ids: Optional[List[str]] = self.get_batch_ids(
             domain=domain,
             variables=variables,
@@ -298,7 +363,7 @@ class ParameterBuilder(Builder, ABC):
         )
         if not batch_ids:
             raise ge_exceptions.ProfilerExecutionError(
-                message=f"Utilizing a {self.__class__.__name__} requires a non-empty list of batch identifiers."
+                message=f"Utilizing a {self.__class__.__name__} requires a non-empty list of Batch identifiers."
             )
 
         """
@@ -323,6 +388,7 @@ class ParameterBuilder(Builder, ABC):
         )
 
         batch_id: str
+
         metric_domain_kwargs = [
             copy.deepcopy(
                 build_metric_domain_kwargs(
@@ -354,7 +420,7 @@ class ParameterBuilder(Builder, ABC):
             for value_kwargs_cursor in metric_value_kwargs
         ]
 
-        # Step-3: Generate "MetricConfiguration" directives for all "metric_domain_kwargs" / "metric_value_kwargs" pairs.
+        # Step-3: Generate "MetricConfiguration" directives for all "metric_domain_kwargs"/"metric_value_kwargs" pairs.
 
         domain_kwargs_cursor: dict
         kwargs_combinations: List[List[dict]] = [
@@ -363,8 +429,10 @@ class ParameterBuilder(Builder, ABC):
             for domain_kwargs_cursor in metric_domain_kwargs
         ]
 
+        metrics_to_resolve: List[MetricConfiguration]
+
         kwargs_pair_cursor: List[dict, dict]
-        metrics_to_resolve: List[MetricConfiguration] = [
+        metrics_to_resolve = [
             MetricConfiguration(
                 metric_name=metric_name,
                 metric_domain_kwargs=kwargs_pair_cursor[0],
@@ -374,7 +442,18 @@ class ParameterBuilder(Builder, ABC):
             for kwargs_pair_cursor in kwargs_combinations
         ]
 
-        # Step-4: Resolve all metrics in one operation simultaneously.
+        # Step-4: Sort "MetricConfiguration" directives by "metric_value_kwargs_id" and "batch_id" (in that order).
+        # This precise sort order enables pairing every metric value with its respective "batch_id" (e.g., for display).
+
+        metrics_to_resolve = sorted(
+            metrics_to_resolve,
+            key=lambda metric_configuration_element: (
+                metric_configuration_element.metric_value_kwargs_id,
+                metric_configuration_element.metric_domain_kwargs["batch_id"],
+            ),
+        )
+
+        # Step-5: Resolve all metrics in one operation simultaneously.
 
         # The Validator object used for metric calculation purposes.
         validator: "Validator" = self.get_validator(  # noqa: F821
@@ -387,70 +466,81 @@ class ParameterBuilder(Builder, ABC):
             metric_configurations=metrics_to_resolve
         )
 
-        # Step-5: Map resolved metrics to their attributes for identification and recovery by receiver.
+        # Step-6: Sort resolved metrics according to same sort order as was applied to "MetricConfiguration" directives.
+
+        resolved_metrics_sorted: Dict[Tuple[str, str, str], Any] = {}
 
         metric_configuration: MetricConfiguration
-        attributed_resolved_metrics_map: Dict[str, AttributedResolvedMetrics] = {}
+
+        resolved_metric_value: Any
+
         for metric_configuration in metrics_to_resolve:
-            attributed_resolved_metrics: AttributedResolvedMetrics = (
-                attributed_resolved_metrics_map.get(
-                    metric_configuration.metric_value_kwargs_id
+            if metric_configuration.id not in resolved_metrics:
+                logger.warning(
+                    f"{metric_configuration.id[0]} was not found in the resolved Metrics for ParameterBuilder."
                 )
+                continue
+
+            resolved_metrics_sorted[metric_configuration.id] = resolved_metrics[
+                metric_configuration.id
+            ]
+
+        # Step-7: Map resolved metrics to their attributes for identification and recovery by receiver.
+
+        attributed_resolved_metrics_map: Dict[str, AttributedResolvedMetrics] = {}
+
+        attributed_resolved_metrics: AttributedResolvedMetrics
+
+        for metric_configuration in metrics_to_resolve:
+            attributed_resolved_metrics = attributed_resolved_metrics_map.get(
+                metric_configuration.metric_value_kwargs_id
             )
             if attributed_resolved_metrics is None:
                 attributed_resolved_metrics = AttributedResolvedMetrics(
                     metric_attributes=metric_configuration.metric_value_kwargs,
-                    metric_values=[],
+                    metric_values_by_batch_id=None,
                 )
                 attributed_resolved_metrics_map[
                     metric_configuration.metric_value_kwargs_id
                 ] = attributed_resolved_metrics
 
-            resolved_metric_value: Union[
-                Tuple[str, str, str], None
-            ] = resolved_metrics.get(metric_configuration.id)
-            if resolved_metric_value is None:
-                raise ge_exceptions.ProfilerExecutionError(
-                    f"{metric_configuration.id[0]} was not found in the resolved Metrics for ParameterBuilder."
+            if metric_configuration.id in resolved_metrics_sorted:
+                resolved_metric_value = resolved_metrics_sorted[metric_configuration.id]
+                attributed_resolved_metrics.add_resolved_metric(
+                    batch_id=metric_configuration.metric_domain_kwargs["batch_id"],
+                    value=resolved_metric_value,
                 )
+            else:
+                continue
 
-            attributed_resolved_metrics.add_resolved_metric(value=resolved_metric_value)
+        # Step-8: Convert scalar metric values to vectors to enable uniformity of processing in subsequent operations.
 
         metric_attributes_id: str
-        metric_values: AttributedResolvedMetrics
-
-        # Step-6: Leverage Numpy Array capabilities for subsequent operations on results of computed/resolved metrics.
-
-        attributed_resolved_metrics_map = {
-            metric_attributes_id: AttributedResolvedMetrics(
-                metric_attributes=metric_values.metric_attributes,
-                metric_values=np.array(metric_values.metric_values),
-            )
-            for metric_attributes_id, metric_values in attributed_resolved_metrics_map.items()
-        }
-
-        # Step-7: Convert scalar metric values to vectors to enable uniformity of processing in subsequent operations.
-
-        idx: int
         for (
             metric_attributes_id,
-            metric_values,
+            attributed_resolved_metrics,
         ) in attributed_resolved_metrics_map.items():
-            if metric_values.metric_values.ndim == 1:
-                metric_values.metric_values = [
-                    [metric_values.metric_values[idx]] for idx in range(len(batch_ids))
-                ]
-                metric_values.metric_values = np.array(metric_values.metric_values)
-                attributed_resolved_metrics_map[metric_attributes_id] = metric_values
+            if (
+                isinstance(attributed_resolved_metrics.metric_values, np.ndarray)
+                and attributed_resolved_metrics.metric_values.ndim == 1
+            ):
+                attributed_resolved_metrics.metric_values_by_batch_id = {
+                    batch_id: [resolved_metric_value]
+                    for batch_id, resolved_metric_value in attributed_resolved_metrics.attributed_metric_values.items()
+                }
+                attributed_resolved_metrics_map[
+                    metric_attributes_id
+                ] = attributed_resolved_metrics
+
+        # Step-9: Apply numeric/hygiene flags (e.g., "enforce_numeric_metric", "replace_nan_with_zero") to results.
 
-        # Step-8: Apply numeric/hygiene directives (e.g., "enforce_numeric_metric", "replace_nan_with_zero") to results.
         for (
             metric_attributes_id,
-            metric_values,
+            attributed_resolved_metrics,
         ) in attributed_resolved_metrics_map.items():
             self._sanitize_metric_computation(
                 metric_name=metric_name,
-                metric_values=metric_values.metric_values,
+                attributed_resolved_metrics=attributed_resolved_metrics,
                 enforce_numeric_metric=enforce_numeric_metric,
                 replace_nan_with_zero=replace_nan_with_zero,
                 domain=domain,
@@ -458,9 +548,10 @@ class ParameterBuilder(Builder, ABC):
                 parameters=parameters,
             )
 
-        # Step-9: Compose and return result to receiver (apply simplifications to cases of single "metric_value_kwargs").
+        # Step-10: Build and return result to receiver (apply simplifications to cases of single "metric_value_kwargs").
+
         return MetricComputationResult(
-            list(attributed_resolved_metrics_map.values()),
+            attributed_resolved_metrics=list(attributed_resolved_metrics_map.values()),
             details={
                 "metric_configuration": {
                     "metric_name": metric_name,
@@ -477,13 +568,13 @@ class ParameterBuilder(Builder, ABC):
     def _sanitize_metric_computation(
         self,
         metric_name: str,
-        metric_values: np.ndarray,
+        attributed_resolved_metrics: AttributedResolvedMetrics,
         enforce_numeric_metric: Union[str, bool] = False,
         replace_nan_with_zero: Union[str, bool] = False,
         domain: Optional[Domain] = None,
         variables: Optional[ParameterContainer] = None,
         parameters: Optional[Dict[str, ParameterContainer]] = None,
-    ) -> np.ndarray:
+    ) -> AttributedResolvedMetrics:
         """
         This method conditions (or "sanitizes") data samples in the format "N x R^m", where "N" (most significant
         dimension) is the number of measurements (e.g., one per Batch of data), while "R^m" is the multi-dimensional
@@ -510,6 +601,11 @@ class ParameterBuilder(Builder, ABC):
             parameters=parameters,
         )
 
+        if not (enforce_numeric_metric or replace_nan_with_zero):
+            return attributed_resolved_metrics
+
+        metric_values: MetricValues = attributed_resolved_metrics.metric_values
+
         # Outer-most dimension is data samples (e.g., one per Batch); the rest are dimensions of the actual metric.
         metric_value_shape: tuple = metric_values.shape[1:]
 
@@ -531,9 +627,11 @@ class ParameterBuilder(Builder, ABC):
 
         # Traverse indices of sample vectors corresponding to every element of multi-dimensional metric.
         metric_value_vector: np.ndarray
+        batch_id: str
+        resolved_metric_value: Any
         for metric_value_idx in metric_value_vector_indices:
             # Obtain "N"-element-long vector of samples for each element of multi-dimensional metric.
-            metric_value_vector = metric_values[metric_value_idx]
+            metric_value_vector = cast(np.ndarray, metric_values)[metric_value_idx]
             if enforce_numeric_metric:
                 if not np.issubdtype(metric_value_vector.dtype, np.number):
                     raise ge_exceptions.ProfilerExecutionError(
@@ -549,14 +647,58 @@ class ParameterBuilder(Builder, ABC):
 """
                         )
 
-                    np.nan_to_num(metric_value_vector, copy=False, nan=0.0)
+                    attributed_resolved_metrics.metric_values_by_batch_id = {
+                        batch_id: np.nan_to_num(
+                            metric_value_vector, copy=False, nan=0.0
+                        )
+                        for batch_id, resolved_metric_value in attributed_resolved_metrics.attributed_metric_values.items()
+                    }
 
-        return metric_values
+        return attributed_resolved_metrics
+
+    @staticmethod
+    def _get_best_candidate_above_threshold(
+        candidate_ratio_dict: Dict[str, float],
+        threshold: float,
+    ) -> Tuple[Optional[str], float]:
+        """
+        Helper method to calculate which candidate strings or patterns are the best match (ie. highest ratio),
+        provided they are also above the threshold.
+        """
+        best_candidate: Optional[str] = None
+        best_ratio: float = 0.0
+
+        candidate: str
+        ratio: float
+        for candidate, ratio in candidate_ratio_dict.items():
+            if ratio > best_ratio and ratio >= threshold:
+                best_candidate = candidate
+                best_ratio = ratio
+
+        return best_candidate, best_ratio
+
+    @staticmethod
+    def _get_sorted_candidates_and_ratios(
+        candidate_ratio_dict: Dict[str, float],
+    ) -> Dict[str, float]:
+        """
+        Helper method to sort all candidate strings or patterns by success ratio (how well they matched the domain).
+
+        Returns sorted dict of candidate as key and ratio as value
+        """
+        # noinspection PyTypeChecker
+        return dict(
+            sorted(
+                candidate_ratio_dict.items(),
+                key=lambda element: element[1],
+                reverse=True,
+            )
+        )
 
 
 def init_rule_parameter_builders(
     parameter_builder_configs: Optional[List[dict]] = None,
-    data_context: Optional["DataContext"] = None,  # noqa: F821
+    data_context: Optional["BaseDataContext"] = None,  # noqa: F821
 ) -> Optional[List["ParameterBuilder"]]:  # noqa: F821
     if parameter_builder_configs is None:
         return None
@@ -572,7 +714,7 @@ def init_rule_parameter_builders(
 
 def init_parameter_builder(
     parameter_builder_config: Union["ParameterBuilderConfig", dict],  # noqa: F821
-    data_context: Optional["DataContext"] = None,  # noqa: F821
+    data_context: Optional["BaseDataContext"] = None,  # noqa: F821
 ) -> "ParameterBuilder":  # noqa: F821
     if not isinstance(parameter_builder_config, dict):
         parameter_builder_config = parameter_builder_config.to_dict()
@@ -589,10 +731,11 @@ def init_parameter_builder(
 
 def resolve_evaluation_dependencies(
     parameter_builder: "ParameterBuilder",  # noqa: F821
-    parameter_container: ParameterContainer,
     domain: Domain,
     variables: Optional[ParameterContainer] = None,
     parameters: Optional[Dict[str, ParameterContainer]] = None,
+    fully_qualified_parameter_names: Optional[List[str]] = None,
+    recompute_existing_parameter_values: bool = False,
 ) -> None:
     """
     This method computes ("resolves") pre-requisite ("evaluation") dependencies (i.e., results of executing other
@@ -603,17 +746,19 @@ def resolve_evaluation_dependencies(
     evaluation_parameter_builders: List[
         "ParameterBuilder"  # noqa: F821
     ] = parameter_builder.evaluation_parameter_builders
+
     if not evaluation_parameter_builders:
         return
 
     # Step-2: Obtain all fully-qualified parameter names ("variables" and "parameter" keys) in namespace of "Domain"
     # (fully-qualified parameter names are stored in "ParameterNode" objects of "ParameterContainer" of "Domain"
     # whenever "ParameterBuilder.build_parameters()" is executed for "ParameterBuilder.fully_qualified_parameter_name").
-    fully_qualified_parameter_names: List[str] = get_fully_qualified_parameter_names(
-        domain=domain,
-        variables=variables,
-        parameters=parameters,
-    )
+    if fully_qualified_parameter_names is None:
+        fully_qualified_parameter_names = get_fully_qualified_parameter_names(
+            domain=domain,
+            variables=variables,
+            parameters=parameters,
+        )
 
     # Step-3: Check for presence of fully-qualified parameter names of "ParameterBuilder" objects, obtained by iterating
     # over evaluation dependencies.  "Execute ParameterBuilder.build_parameters()" if absent from "Domain" scoped list.
@@ -630,22 +775,21 @@ def resolve_evaluation_dependencies(
             evaluation_parameter_builder.set_batch_list_or_batch_request(
                 batch_list=parameter_builder.batch_list,
                 batch_request=parameter_builder.batch_request,
-                force_batch_data=False,
             )
 
             evaluation_parameter_builder.build_parameters(
-                parameter_container=parameter_container,
                 domain=domain,
                 variables=variables,
                 parameters=parameters,
+                recompute_existing_parameter_values=recompute_existing_parameter_values,
             )
 
             # Step-4: Any "ParameterBuilder" object, including members of "evaluation_parameter_builders" list may be
             # configured with its own "evaluation_parameter_builders" list.  Recursive call handles such situations.
             resolve_evaluation_dependencies(
                 parameter_builder=evaluation_parameter_builder,
-                parameter_container=parameter_container,
                 domain=domain,
                 variables=variables,
                 parameters=parameters,
+                recompute_existing_parameter_values=recompute_existing_parameter_values,
             )
