@@ -1,8 +1,8 @@
 import logging
-from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Union
+from typing import Dict, Iterable, List, Optional, Set, Union
 
 import great_expectations.exceptions as ge_exceptions
-from great_expectations.core.batch import Batch, BatchRequest, RuntimeBatchRequest
+from great_expectations.rule_based_profiler.config import ParameterBuilderConfig
 from great_expectations.rule_based_profiler.helpers.util import (
     get_parameter_value_and_validate_return_type,
 )
@@ -13,10 +13,12 @@ from great_expectations.rule_based_profiler.parameter_builder import (
     ParameterBuilder,
 )
 from great_expectations.rule_based_profiler.types import (
-    PARAMETER_KEY,
+    FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY,
+    FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY,
     Domain,
     ParameterContainer,
 )
+from great_expectations.types.attributes import Attributes
 
 logger = logging.getLogger(__name__)
 
@@ -32,16 +34,16 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
     # source: https://regexland.com/most-common-regular-expressions/
     # source for UUID: https://stackoverflow.com/questions/7905929/how-to-test-valid-uuid-guid/13653180#13653180
     CANDIDATE_REGEX: Set[str] = {
-        r"/\d+/",  # whole number with 1 or more digits
-        r"/-?\d+/",  # negative whole numbers
-        r"/-?\d+(\.\d*)?/",  # decimal numbers with . (period) separator
-        r"/[A-Za-z0-9\.,;:!?()\"'%\-]+/",  # general text
-        r"^\s+/",  # leading space
-        r"\s+/$",  # trailing space
-        r"/https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#()?&//=]*)/",  #  Matching URL (including http(s) protocol)
-        r"/<\/?(?:p|a|b|img)(?: \/)?>/",  # HTML tags
-        r"/(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}/",  # IPv4 IP address
-        r"/(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}/",  # IPv6 IP address,
+        r"\d+",  # whole number with 1 or more digits
+        r"-?\d+",  # negative whole numbers
+        r"-?\d+(\.\d*)?",  # decimal numbers with . (period) separator
+        r"[A-Za-z0-9\.,;:!?()\"'%\-]+",  # general text
+        r"^\s+",  # leading space
+        r"\s+$",  # trailing space
+        r"https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#()?&//=]*)",  #  Matching URL (including http(s) protocol)
+        r"<\/?(?:p|a|b|img)(?: \/)?>",  # HTML tags
+        r"(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}",  # IPv4 IP address
+        r"(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}",  # IPv6 IP address,
         r"\b[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}-[0-5][0-9a-fA-F]{3}-[089ab][0-9a-fA-F]{3}-\b[0-9a-fA-F]{12}\b ",  # UUID
     }
 
@@ -52,14 +54,12 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
         metric_value_kwargs: Optional[Union[str, dict]] = None,
         threshold: Union[str, float] = 1.0,
         candidate_regexes: Optional[Union[str, Iterable[str]]] = None,
-        evaluation_parameter_builder_configs: Optional[List[dict]] = None,
-        json_serialize: Union[str, bool] = True,
-        batch_list: Optional[List[Batch]] = None,
-        batch_request: Optional[
-            Union[str, BatchRequest, RuntimeBatchRequest, dict]
+        evaluation_parameter_builder_configs: Optional[
+            List[ParameterBuilderConfig]
         ] = None,
-        data_context: Optional["DataContext"] = None,  # noqa: F821
-    ):
+        json_serialize: Union[str, bool] = True,
+        data_context: Optional["BaseDataContext"] = None,  # noqa: F821
+    ) -> None:
         """
         Configure this RegexPatternStringParameterBuilder
         Args:
@@ -72,16 +72,12 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
             ParameterBuilder objects' outputs available (as fully-qualified parameter names) is pre-requisite.
             These "ParameterBuilder" configurations help build parameters needed for this "ParameterBuilder".
             json_serialize: If True (default), convert computed value to JSON prior to saving results.
-            batch_list: Optional[List[Batch]] = None,
-            batch_request: specified in ParameterBuilder configuration to get Batch objects for parameter computation.
-            data_context: DataContext
+            data_context: BaseDataContext associated with this ParameterBuilder
         """
         super().__init__(
             name=name,
             evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
             json_serialize=json_serialize,
-            batch_list=batch_list,
-            batch_request=batch_request,
             data_context=data_context,
         )
 
@@ -92,14 +88,6 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
 
         self._candidate_regexes = candidate_regexes
 
-    @property
-    def fully_qualified_parameter_name(self) -> str:
-        return f"{PARAMETER_KEY}{self.name}"
-
-    """
-    Full getter/setter accessors for needed properties are for configuring MetricMultiBatchParameterBuilder dynamically.
-    """
-
     @property
     def metric_domain_kwargs(self) -> Optional[Union[str, dict]]:
         return self._metric_domain_kwargs
@@ -124,16 +112,18 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
 
     def _build_parameters(
         self,
-        parameter_container: ParameterContainer,
         domain: Domain,
         variables: Optional[ParameterContainer] = None,
         parameters: Optional[Dict[str, ParameterContainer]] = None,
-    ) -> Tuple[Any, dict]:
+        recompute_existing_parameter_values: bool = False,
+    ) -> Attributes:
         """
-        Check the percentage of values matching the REGEX string, and return the best fit, or None if no
-        string exceeds the configured threshold.
+        Builds ParameterContainer object that holds ParameterNode objects with attribute name-value pairs and details.
 
-        return: Tuple containing computed_parameter_value and parameter_computation_details metadata.
+        Check the percentage of values matching the REGEX string, and return the best fit, or None if no string exceeds
+        the configured threshold.
+
+        Builds ParameterContainer object that holds ParameterNode objects with attribute name-value pairs and details.
         """
         metric_computation_result: MetricComputationResult
 
@@ -147,22 +137,26 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
         )
 
         # This should never happen.
-        if not (
-            isinstance(metric_computation_result.metric_values, list)
-            and len(metric_computation_result.metric_values) == 1
-        ):
+        if len(metric_computation_result.attributed_resolved_metrics) != 1:
             raise ge_exceptions.ProfilerExecutionError(
-                message=f'Result of metric computations for {self.__class__.__name__} must be a list with exactly 1 element of type "AttributedResolvedMetrics" ({metric_computation_result.metric_values} found).'
+                message=f'Result of metric computations for {self.__class__.__name__} must be a list with exactly 1 element of type "AttributedResolvedMetrics" ({metric_computation_result.attributed_resolved_metrics} found).'
             )
 
         attributed_resolved_metrics: AttributedResolvedMetrics
 
-        attributed_resolved_metrics = metric_computation_result.metric_values[0]
+        attributed_resolved_metrics = (
+            metric_computation_result.attributed_resolved_metrics[0]
+        )
 
         metric_values: MetricValues
 
         metric_values = attributed_resolved_metrics.metric_values
 
+        if metric_values is None:
+            raise ge_exceptions.ProfilerExecutionError(
+                message=f"Result of metric computations for {self.__class__.__name__} is empty."
+            )
+
         # Now obtain 1-dimensional vector of values of computed metric (each element corresponds to a Batch ID).
         metric_values = metric_values[:, 0]
 
@@ -213,7 +207,9 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
 
         regex_string_success_ratios: dict = {}
 
-        for attributed_resolved_metrics in metric_computation_result.metric_values:
+        for (
+            attributed_resolved_metrics
+        ) in metric_computation_result.attributed_resolved_metrics:
             # Now obtain 1-dimensional vector of values of computed metric (each element corresponds to a Batch ID).
             metric_values = attributed_resolved_metrics.metric_values[:, 0]
 
@@ -234,63 +230,26 @@ class RegexPatternStringParameterBuilder(ParameterBuilder):
             parameters=parameters,
         )
 
-        # get list of regex_strings that match greater than threshold
-        regex_string_success_list: List[
-            str
-        ] = self._get_regex_matched_greater_than_threshold(
+        # get best-matching regex_string that match greater than threshold
+        (
+            best_regex_string,
+            best_ratio,
+        ) = ParameterBuilder._get_best_candidate_above_threshold(
             regex_string_success_ratios, threshold
         )
-        # sorted regex and ratios for all evaluated candidates
-        sorted_ratio_list, sorted_regex_string_list = self._get_sorted_regex_and_ratios(
-            regex_string_success_ratios
+        # dict of sorted regex and ratios for all evaluated candidates
+        sorted_regex_candidates_and_ratios: dict = (
+            ParameterBuilder._get_sorted_candidates_and_ratios(
+                regex_string_success_ratios
+            )
         )
 
-        return (
-            regex_string_success_list,
+        return Attributes(
             {
-                "evaluated_regexes": dict(
-                    zip(sorted_regex_string_list, sorted_ratio_list)
-                ),
-                "threshold": threshold,
-            },
+                FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY: best_regex_string,
+                FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY: {
+                    "success_ratio": best_ratio,
+                    "evaluated_regexes": sorted_regex_candidates_and_ratios,
+                },
+            }
         )
-
-    @staticmethod
-    def _get_regex_matched_greater_than_threshold(
-        regex_string_success_ratio_dict: Dict[str, float],
-        threshold: float,
-    ) -> List[str]:
-        """
-        Helper method to calculate which regex_strings match greater than threshold
-        """
-        regex_string: str
-        ratio: float
-        regex_string_success_list: List[str] = [
-            regex_string
-            for regex_string, ratio in regex_string_success_ratio_dict.items()
-            if ratio >= threshold
-        ]
-
-        return regex_string_success_list
-
-    @staticmethod
-    def _get_sorted_regex_and_ratios(
-        regex_string_success_ratio_dict: Dict[str, float],
-    ) -> Tuple[List[float], List[str]]:
-        """
-        Helper method to sort all regexes that were evaluated by their success ratio.
-
-        Returns Tuple(ratio, sorted_strings)
-        """
-        regex_strings: List[str] = list(regex_string_success_ratio_dict.keys())
-        ratios: List[float] = list(regex_string_success_ratio_dict.values())
-
-        regex_string: str
-        ratio: float
-        sorted_regex_strings: List[str] = [
-            regex_string
-            for ratio, regex_string in sorted(zip(ratios, regex_strings), reverse=True)
-        ]
-        ratios.sort(reverse=True)
-
-        return ratios, sorted_regex_strings
