@@ -1,8 +1,8 @@
 import copy
 import json
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
-from great_expectations.core import ExpectationConfiguration
+from great_expectations.core.batch import Batch, BatchRequestBase
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.rule_based_profiler.config.base import (
     domainBuilderConfigSchema,
@@ -13,8 +13,21 @@ from great_expectations.rule_based_profiler.domain_builder import DomainBuilder
 from great_expectations.rule_based_profiler.expectation_configuration_builder import (
     ExpectationConfigurationBuilder,
 )
+from great_expectations.rule_based_profiler.helpers.configuration_reconciliation import (
+    DEFAULT_RECONCILATION_DIRECTIVES,
+    ReconciliationDirectives,
+    reconcile_rule_variables,
+)
+from great_expectations.rule_based_profiler.helpers.util import (
+    convert_variables_to_dict,
+)
 from great_expectations.rule_based_profiler.parameter_builder import ParameterBuilder
-from great_expectations.rule_based_profiler.types import Domain, ParameterContainer
+from great_expectations.rule_based_profiler.types import (
+    Domain,
+    ParameterContainer,
+    RuleState,
+    build_parameter_container_for_variables,
+)
 from great_expectations.types import SerializableDictDot
 from great_expectations.util import deep_filter_properties_iterable
 
@@ -23,72 +36,124 @@ class Rule(SerializableDictDot):
     def __init__(
         self,
         name: str,
-        domain_builder: DomainBuilder,
-        expectation_configuration_builders: List[ExpectationConfigurationBuilder],
+        variables: Optional[Union[ParameterContainer, Dict[str, Any]]] = None,
+        domain_builder: Optional[DomainBuilder] = None,
         parameter_builders: Optional[List[ParameterBuilder]] = None,
-    ):
+        expectation_configuration_builders: Optional[
+            List[ExpectationConfigurationBuilder]
+        ] = None,
+    ) -> None:
         """
-        Sets Profiler rule name, domain builders, parameters builders, configuration builders,
-        and other necessary instance data (variables)
-        :param name: A string representing the name of the ProfilerRule
-        :param domain_builder: A Domain Builder object used to build rule data domain
-        :param parameter_builders: A Parameter Builder list used to configure necessary rule evaluation parameters for
-        every configuration
-        :param expectation_configuration_builders: A list of Expectation Configuration Builders
+        Sets Rule name, variables, domain builder, parameters builders, configuration builders, and other instance data.
+
+        Args:
+            name: A string representing the name of the ProfilerRule
+            variables: Any variables to be substituted within the rules
+            domain_builder: A Domain Builder object used to build rule data domain
+            parameter_builders: A Parameter Builder list used to configure necessary rule evaluation parameters
+            expectation_configuration_builders: A list of Expectation Configuration Builders
         """
         self._name = name
+
+        if variables is None:
+            variables = {}
+
+        # Convert variables argument to ParameterContainer
+        _variables: ParameterContainer
+        if isinstance(variables, ParameterContainer):
+            _variables = variables
+        else:
+            _variables: ParameterContainer = build_parameter_container_for_variables(
+                variables_configs=variables
+            )
+
+        self.variables = _variables
+
         self._domain_builder = domain_builder
         self._parameter_builders = parameter_builders
         self._expectation_configuration_builders = expectation_configuration_builders
 
-        self._parameters = {}
-
-    def generate(
+    def run(
         self,
         variables: Optional[ParameterContainer] = None,
-    ) -> List[ExpectationConfiguration]:
+        batch_list: Optional[List[Batch]] = None,
+        batch_request: Optional[Union[BatchRequestBase, dict]] = None,
+        recompute_existing_parameter_values: bool = False,
+        reconciliation_directives: ReconciliationDirectives = DEFAULT_RECONCILATION_DIRECTIVES,
+    ) -> RuleState:
         """
         Builds a list of Expectation Configurations, returning a single Expectation Configuration entry for every
         ConfigurationBuilder available based on the instantiation.
 
-        :return: List of Corresponding Expectation Configurations representing every configured rule
-        """
-        expectation_configurations: List[ExpectationConfiguration] = []
+        Args:
+            variables: Attribute name/value pairs, commonly-used in Builder objects
+            batch_list: Explicit list of Batch objects to supply data at runtime
+            batch_request: Explicit batch_request used to supply data at runtime
+            recompute_existing_parameter_values: If "True", recompute value if "fully_qualified_parameter_name" exists
+            reconciliation_directives: directives for how each rule component should be overwritten
 
-        domains: List[Domain] = self.domain_builder.get_domains(variables=variables)
+        Returns:
+            RuleState representing effect of executing Rule
+        """
+        variables = build_parameter_container_for_variables(
+            variables_configs=reconcile_rule_variables(
+                variables=variables,
+                variables_config=convert_variables_to_dict(variables=self.variables),
+                reconciliation_strategy=reconciliation_directives.variables,
+            )
+        )
+        domains: List[Domain] = (
+            []
+            if self.domain_builder is None
+            else self.domain_builder.get_domains(
+                rule_name=self.name,
+                variables=variables,
+                batch_list=batch_list,
+                batch_request=batch_request,
+            )
+        )
+        rule_state: RuleState = RuleState(
+            rule=self,
+            variables=variables,
+            domains=domains,
+        )
+        rule_state.reset_parameter_containers()
 
         domain: Domain
         for domain in domains:
-            parameter_container: ParameterContainer = ParameterContainer(
-                parameter_nodes=None
-            )
-            self._parameters[domain.id] = parameter_container
+            rule_state.initialize_parameter_container_for_domain(domain=domain)
 
             parameter_builders: List[ParameterBuilder] = self.parameter_builders or []
             parameter_builder: ParameterBuilder
             for parameter_builder in parameter_builders:
                 parameter_builder.build_parameters(
-                    parameter_container=parameter_container,
                     domain=domain,
                     variables=variables,
-                    parameters=self._parameters,
+                    parameters=rule_state.parameters,
+                    parameter_computation_impl=None,
+                    json_serialize=None,
+                    batch_list=batch_list,
+                    batch_request=batch_request,
+                    recompute_existing_parameter_values=recompute_existing_parameter_values,
                 )
 
             expectation_configuration_builders: List[
                 ExpectationConfigurationBuilder
             ] = (self.expectation_configuration_builders or [])
+
             expectation_configuration_builder: ExpectationConfigurationBuilder
+
             for expectation_configuration_builder in expectation_configuration_builders:
-                expectation_configurations.append(
-                    expectation_configuration_builder.build_expectation_configuration(
-                        parameter_container=parameter_container,
-                        domain=domain,
-                        variables=variables,
-                        parameters=self._parameters,
-                    )
+                expectation_configuration_builder.resolve_validation_dependencies(
+                    domain=domain,
+                    variables=variables,
+                    parameters=rule_state.parameters,
+                    batch_list=batch_list,
+                    batch_request=batch_request,
+                    recompute_existing_parameter_values=recompute_existing_parameter_values,
                 )
 
-        return expectation_configurations
+        return rule_state
 
     @property
     def name(self) -> str:
@@ -99,7 +164,16 @@ class Rule(SerializableDictDot):
         self._name = value
 
     @property
-    def domain_builder(self) -> DomainBuilder:
+    def variables(self) -> Optional[ParameterContainer]:
+        # Returning a copy of the "self._variables" state variable in order to prevent write-before-read hazard.
+        return copy.deepcopy(self._variables)
+
+    @variables.setter
+    def variables(self, value: Optional[ParameterContainer]) -> None:
+        self._variables = value
+
+    @property
+    def domain_builder(self) -> Optional[DomainBuilder]:
         return self._domain_builder
 
     @property
@@ -109,14 +183,9 @@ class Rule(SerializableDictDot):
     @property
     def expectation_configuration_builders(
         self,
-    ) -> List[ExpectationConfigurationBuilder]:
+    ) -> Optional[List[ExpectationConfigurationBuilder]]:
         return self._expectation_configuration_builders
 
-    @property
-    def parameters(self) -> Dict[str, ParameterContainer]:
-        # Returning a copy of the "self._parameters" state variable in order to prevent write-before-read hazard.
-        return copy.deepcopy(self._parameters)
-
     def to_dict(self) -> dict:
         parameter_builder_configs: Optional[List[dict]] = None
         parameter_builders: Optional[
@@ -162,6 +231,10 @@ class Rule(SerializableDictDot):
         make this refactoring infeasible at the present time.
         """
         dict_obj: dict = self.to_dict()
+        variables_dict: Optional[Dict[str, Any]] = convert_variables_to_dict(
+            variables=self.variables
+        )
+        dict_obj["variables"] = variables_dict
         serializeable_dict: dict = convert_to_json_serializable(data=dict_obj)
         return serializeable_dict
 
@@ -204,8 +277,14 @@ class Rule(SerializableDictDot):
     def _get_expectation_configuration_builders_as_dict(
         self,
     ) -> Dict[str, ExpectationConfigurationBuilder]:
+        expectation_configuration_builders: List[
+            ExpectationConfigurationBuilder
+        ] = self.expectation_configuration_builders
+        if expectation_configuration_builders is None:
+            expectation_configuration_builders = []
+
         expectation_configuration_builder: ExpectationConfigurationBuilder
         return {
             expectation_configuration_builder.expectation_type: expectation_configuration_builder
-            for expectation_configuration_builder in self.expectation_configuration_builders
+            for expectation_configuration_builder in expectation_configuration_builders
         }
