@@ -12,6 +12,8 @@ from great_expectations.util import (
     filter_properties_dict,
 )
 
+INFERRED_SEMANTIC_TYPE_KEY: str = "inferred_semantic_domain_type"
+
 
 class SemanticDomainTypes(Enum):
     NUMERIC = "numeric"
@@ -49,13 +51,14 @@ class Domain(SerializableDotDict):
     # Adding an explicit constructor to highlight the specific properties that will be used.
     def __init__(
         self,
+        rule_name: str,
         domain_type: Union[str, MetricDomainTypes],
         domain_kwargs: Optional[Union[Dict[str, Any], DomainKwargs]] = None,
         details: Optional[Dict[str, Any]] = None,
-    ):
+    ) -> None:
         if isinstance(domain_type, str):
             try:
-                domain_type = MetricDomainTypes[domain_type]
+                domain_type = MetricDomainTypes(domain_type)
             except (TypeError, KeyError) as e:
                 raise ValueError(
                     f""" \
@@ -82,6 +85,7 @@ Cannot instantiate Domain (domain_type "{str(domain_type)}" of type "{str(type(d
             details = {}
 
         super().__init__(
+            rule_name=rule_name,
             domain_type=domain_type,
             domain_kwargs=domain_kwargs_dot_dict,
             details=details,
@@ -101,7 +105,9 @@ Cannot instantiate Domain (domain_type "{str(domain_type)}" of type "{str(type(d
             )
             or (
                 isinstance(other, dict)
-                and self.to_json_dict()
+                and filter_properties_dict(
+                    properties=self.to_json_dict(), clean_falsy=True
+                )
                 == filter_properties_dict(properties=other, clean_falsy=True)
             )
             or (self.__str__() == str(other))
@@ -110,17 +116,43 @@ Cannot instantiate Domain (domain_type "{str(domain_type)}" of type "{str(type(d
     def __ne__(self, other):
         return not self.__eq__(other=other)
 
+    def __hash__(self) -> int:
+        """Overrides the default implementation"""
+        _result_hash: int = hash(self.id)
+        return _result_hash
+
     # Adding this property for convenience (also, in the future, arguments may not be all set to their default values).
     @property
     def id(self) -> str:
         return IDDict(self.to_json_dict()).to_id()
 
     def to_json_dict(self) -> dict:
+        details: dict = {}
+
+        key: str
+        value: Any
+        for key, value in self["details"].items():
+            if value:
+                if key == INFERRED_SEMANTIC_TYPE_KEY:
+                    column_name: str
+                    semantic_type: Union[str, SemanticDomainTypes]
+                    value = {
+                        column_name: SemanticDomainTypes(semantic_type.lower()).value
+                        if isinstance(semantic_type, str)
+                        else semantic_type.value
+                        for column_name, semantic_type in value.items()
+                    }
+
+            details[key] = convert_to_json_serializable(data=value)
+
         json_dict: dict = {
+            "rule_name": self["rule_name"],
             "domain_type": self["domain_type"].value,
             "domain_kwargs": self["domain_kwargs"].to_json_dict(),
-            "details": {key: value.value for key, value in self["details"].items()},
+            "details": details,
         }
+        json_dict = convert_to_json_serializable(data=json_dict)
+
         return filter_properties_dict(properties=json_dict, clean_falsy=True)
 
     def _convert_dictionaries_to_domain_kwargs(
