@@ -6,9 +6,6 @@ import pytest
 
 from great_expectations import DataContext
 from great_expectations.checkpoint import Checkpoint
-from great_expectations.core.usage_statistics.anonymizers.checkpoint_anonymizer import (
-    CheckpointAnonymizer,
-)
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.data_context.types.base import CheckpointConfig
 from great_expectations.util import deep_filter_properties_iterable
