@@ -423,7 +423,7 @@ def test_instantiation_with_test_yaml_config(
     context: DataContext = empty_data_context_stats_enabled
 
     report_object = context.test_yaml_config(
-        f"""
+        """
         module_name: great_expectations.datasource.data_connector
         class_name: InferredAssetAzureDataConnector
         datasource_name: FAKE_DATASOURCE
@@ -464,7 +464,7 @@ def test_instantiation_with_test_yaml_config_emits_proper_payload(
     context: DataContext = empty_data_context_stats_enabled
 
     report_object = context.test_yaml_config(
-        f"""
+        """
         module_name: great_expectations.datasource.data_connector
         class_name: InferredAssetAzureDataConnector
         datasource_name: FAKE_DATASOURCE
@@ -521,7 +521,7 @@ def test_instantiation_from_a_config_with_nonmatching_regex_creates_unmatched_re
     context: DataContext = empty_data_context_stats_enabled
 
     report_object = context.test_yaml_config(
-        f"""
+        """
         module_name: great_expectations.datasource.data_connector
         class_name: InferredAssetAzureDataConnector
         datasource_name: FAKE_DATASOURCE
@@ -610,7 +610,7 @@ def test_get_definition_list_from_batch_request_with_empty_args_raises_error(
     mock_azure_conn, mock_list_keys, mock_emit, empty_data_context_stats_enabled
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
            class_name: InferredAssetAzureDataConnector
            datasource_name: test_environment
            container: my_container
@@ -670,7 +670,7 @@ def test_get_definition_list_from_batch_request_with_unnamed_data_asset_name_rai
     mock_azure_conn, mock_list_keys, mock_emit, empty_data_context_stats_enabled
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
            class_name: InferredAssetAzureDataConnector
            datasource_name: test_environment
            container: my_container
@@ -724,7 +724,7 @@ def test_return_all_batch_definitions_unsorted_without_named_data_asset_name(
     expected_batch_definitions_unsorted,
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
            class_name: InferredAssetAzureDataConnector
            datasource_name: test_environment
            container: my_container
@@ -799,7 +799,7 @@ def test_return_all_batch_definitions_unsorted_with_named_data_asset_name(
     expected_batch_definitions_unsorted,
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
            class_name: InferredAssetAzureDataConnector
            datasource_name: test_environment
            container: my_container
@@ -874,7 +874,7 @@ def test_return_all_batch_definitions_basic_sorted(
     expected_batch_definitions_sorted,
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
        class_name: InferredAssetAzureDataConnector
        datasource_name: test_environment
        container: my_container
@@ -959,7 +959,7 @@ def test_return_all_batch_definitions_returns_specified_partition(
     mock_azure_conn, mock_list_keys, mock_emit, empty_data_context_stats_enabled
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
        class_name: InferredAssetAzureDataConnector
        datasource_name: test_environment
        container: my_container
@@ -1074,7 +1074,7 @@ def test_return_all_batch_definitions_sorted_without_data_connector_query(
     expected_batch_definitions_sorted,
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
        class_name: InferredAssetAzureDataConnector
        datasource_name: test_environment
        container: my_container
@@ -1159,7 +1159,7 @@ def test_return_all_batch_definitions_raises_error_due_to_sorter_that_does_not_m
     mock_azure_conn, mock_list_keys, mock_emit, empty_data_context_stats_enabled
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
        class_name: InferredAssetAzureDataConnector
        datasource_name: test_environment
        container: my_container
@@ -1225,7 +1225,7 @@ def test_return_all_batch_definitions_too_many_sorters(
     mock_azure_conn, mock_list_keys, mock_emit, empty_data_context_stats_enabled
 ):
     my_data_connector_yaml = yaml.load(
-        f"""
+        """
        class_name: InferredAssetAzureDataConnector
        datasource_name: test_environment
        container: my_container
@@ -1291,7 +1291,7 @@ def test_return_all_batch_definitions_too_many_sorters(
 def test_get_full_file_path_pandas(
     mock_azure_conn, mock_list_keys, mock_emit, empty_data_context_stats_enabled
 ):
-    yaml_string = f"""
+    yaml_string = """
 class_name: InferredAssetAzureDataConnector
 datasource_name: FAKE_DATASOURCE_NAME
 container: my_container
@@ -1369,7 +1369,7 @@ def test_get_full_file_path_spark(
     empty_data_context_stats_enabled,
     spark_session,
 ):
-    yaml_string = f"""
+    yaml_string = """
 class_name: InferredAssetAzureDataConnector
 datasource_name: FAKE_DATASOURCE_NAME
 container: my_container
@@ -1443,7 +1443,7 @@ azure_options:
 def test_get_full_file_path_bad_execution_engine(
     mock_azure_conn, mock_list_keys, mock_emit, empty_data_context_stats_enabled
 ):
-    yaml_string = f"""
+    yaml_string = """
 class_name: InferredAssetAzureDataConnector
 datasource_name: FAKE_DATASOURCE_NAME
 container: my_container
