@@ -8,6 +8,7 @@ from great_expectations.core.batch import BatchRequest
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.data_context import DataContext
 from great_expectations.data_context.util import file_relative_path
+from great_expectations.execution_engine.execution_engine import MetricDomainTypes
 from great_expectations.rule_based_profiler.domain_builder import (
     ColumnDomainBuilder,
     DomainBuilder,
@@ -20,6 +21,10 @@ from great_expectations.rule_based_profiler.parameter_builder import (
 )
 from great_expectations.rule_based_profiler.rule.rule import Rule
 from great_expectations.rule_based_profiler.rule_based_profiler import RuleBasedProfiler
+from great_expectations.rule_based_profiler.types import (
+    INFERRED_SEMANTIC_TYPE_KEY,
+    SemanticDomainTypes,
+)
 
 
 @pytest.fixture
@@ -82,16 +87,61 @@ def test_domain_builder(data_context_with_taxi_data):
     )
     domain_builder: DomainBuilder = ColumnDomainBuilder(
         include_column_name_suffixes=["_amount"],
-        batch_request=batch_request,
         data_context=context,
     )
-    domains: list = domain_builder.get_domains()
+    domains: list = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
     assert len(domains) == 4
     assert domains == [
-        {"domain_type": "column", "domain_kwargs": {"column": "fare_amount"}},
-        {"domain_type": "column", "domain_kwargs": {"column": "tip_amount"}},
-        {"domain_type": "column", "domain_kwargs": {"column": "tolls_amount"}},
-        {"domain_type": "column", "domain_kwargs": {"column": "total_amount"}},
+        {
+            "rule_name": "my_rule",
+            "domain_type": MetricDomainTypes.COLUMN.value,
+            "domain_kwargs": {
+                "column": "fare_amount",
+            },
+            "details": {
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "fare_amount": SemanticDomainTypes.NUMERIC.value,
+                },
+            },
+        },
+        {
+            "rule_name": "my_rule",
+            "domain_type": MetricDomainTypes.COLUMN.value,
+            "domain_kwargs": {
+                "column": "tip_amount",
+            },
+            "details": {
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "tip_amount": SemanticDomainTypes.NUMERIC.value,
+                },
+            },
+        },
+        {
+            "rule_name": "my_rule",
+            "domain_type": MetricDomainTypes.COLUMN.value,
+            "domain_kwargs": {
+                "column": "tolls_amount",
+            },
+            "details": {
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "tolls_amount": SemanticDomainTypes.NUMERIC.value,
+                },
+            },
+        },
+        {
+            "rule_name": "my_rule",
+            "domain_type": MetricDomainTypes.COLUMN.value,
+            "domain_kwargs": {
+                "column": "total_amount",
+            },
+            "details": {
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "total_amount": SemanticDomainTypes.NUMERIC.value,
+                },
+            },
+        },
     ]
 
 
@@ -116,7 +166,6 @@ def test_add_rule_and_run_profiler(data_context_with_taxi_data):
     )
     domain_builder: DomainBuilder = ColumnDomainBuilder(
         include_column_name_suffixes=["_amount"],
-        batch_request=batch_request.to_json_dict(),
         data_context=context,
     )
     default_expectation_configuration_builder = DefaultExpectationConfigurationBuilder(
@@ -125,6 +174,7 @@ def test_add_rule_and_run_profiler(data_context_with_taxi_data):
     )
     simple_rule: Rule = Rule(
         name="rule_with_no_variables_no_parameters",
+        variables=None,
         domain_builder=domain_builder,
         expectation_configuration_builders=[default_expectation_configuration_builder],
     )
@@ -134,7 +184,8 @@ def test_add_rule_and_run_profiler(data_context_with_taxi_data):
         data_context=context,
     )
     my_rbp.add_rule(rule=simple_rule)
-    res: ExpectationSuite = my_rbp.run()
+    my_rbp.run(batch_request=batch_request)
+    res: ExpectationSuite = my_rbp.get_expectation_suite()
     assert len(res.expectations) == 4
 
 
@@ -155,14 +206,12 @@ def test_profiler_parameter_builder_added(data_context_with_taxi_data):
     )
     domain_builder: DomainBuilder = ColumnDomainBuilder(
         include_column_name_suffixes=["_amount"],
-        batch_request=batch_request.to_json_dict(),
         data_context=context,
     )
     # parameter_builder
     numeric_range_parameter_builder: MetricMultiBatchParameterBuilder = (
         MetricMultiBatchParameterBuilder(
             data_context=context,
-            batch_request=batch_request.to_json_dict(),
             metric_name="column.min",
             metric_domain_kwargs="$domain.domain_kwargs",
             name="my_column_min",
@@ -177,6 +226,7 @@ def test_profiler_parameter_builder_added(data_context_with_taxi_data):
     )
     simple_rule: Rule = Rule(
         name="rule_with_variables_and_parameters",
+        variables=None,
         domain_builder=domain_builder,
         parameter_builders=[numeric_range_parameter_builder],
         expectation_configuration_builders=[config_builder],
@@ -187,7 +237,8 @@ def test_profiler_parameter_builder_added(data_context_with_taxi_data):
         data_context=context,
     )
     my_rbp.add_rule(rule=simple_rule)
-    res: ExpectationSuite = my_rbp.run()
+    my_rbp.run(batch_request=batch_request)
+    res: ExpectationSuite = my_rbp.get_expectation_suite()
     assert len(res.expectations) == 4
 
 
@@ -201,22 +252,14 @@ def test_profiler_save_and_load(data_context_with_taxi_data):
     The test tests that context.save_profiler() and context.get_profiler() return the expected RBP.
     """
     context: DataContext = data_context_with_taxi_data
-    batch_request: BatchRequest = BatchRequest(
-        datasource_name="taxi_multibatch_datasource_other_possibility",
-        data_connector_name="default_inferred_data_connector_name",
-        data_asset_name="yellow_tripdata_sample_2018",
-        data_connector_query={"index": -1},
-    )
     domain_builder: DomainBuilder = ColumnDomainBuilder(
         include_column_name_suffixes=["_amount"],
-        batch_request=batch_request.to_json_dict(),
         data_context=context,
     )
     # parameter_builder
     numeric_range_parameter_builder: MetricMultiBatchParameterBuilder = (
         MetricMultiBatchParameterBuilder(
             data_context=context,
-            batch_request=batch_request.to_json_dict(),
             metric_name="column.min",
             metric_domain_kwargs="$domain.domain_kwargs",
             name="my_column_min",
@@ -231,6 +274,7 @@ def test_profiler_save_and_load(data_context_with_taxi_data):
     )
     simple_variables_rule: Rule = Rule(
         name="rule_with_no_variables_no_parameters",
+        variables=None,
         domain_builder=domain_builder,
         parameter_builders=[numeric_range_parameter_builder],
         expectation_configuration_builders=[config_builder],
@@ -243,11 +287,11 @@ def test_profiler_save_and_load(data_context_with_taxi_data):
     res: dict = my_rbp.config.to_json_dict()
     assert res == {
         "class_name": "RuleBasedProfiler",
-        "module_name": "great_expectations.rule_based_profiler.rule_based_profiler",
+        "module_name": "great_expectations.rule_based_profiler",
         "name": "my_rbp",
         "config_version": 1.0,
         "rules": None,
-        "variables": None,
+        "variables": {},
     }
     my_rbp.add_rule(rule=simple_variables_rule)
     context.save_profiler(name="my_rbp", profiler=my_rbp)
@@ -257,11 +301,11 @@ def test_profiler_save_and_load(data_context_with_taxi_data):
 
     res = my_loaded_profiler.config.to_json_dict()
     assert res == {
-        "module_name": "great_expectations.rule_based_profiler.rule_based_profiler",
+        "module_name": "great_expectations.rule_based_profiler",
         "class_name": "RuleBasedProfiler",
         "name": "my_rbp",
         "config_version": 1.0,
-        "variables": None,
+        "variables": {},
         "rules": {
             "rule_with_no_variables_no_parameters": {
                 "domain_builder": {
@@ -270,15 +314,8 @@ def test_profiler_save_and_load(data_context_with_taxi_data):
                     "include_column_name_suffixes": [
                         "_amount",
                     ],
-                    "batch_request": {
-                        "datasource_name": "taxi_multibatch_datasource_other_possibility",
-                        "data_connector_name": "default_inferred_data_connector_name",
-                        "data_asset_name": "yellow_tripdata_sample_2018",
-                        "batch_spec_passthrough": None,
-                        "data_connector_query": {"index": -1},
-                        "limit": None,
-                    },
                 },
+                "variables": {},
                 "parameter_builders": [
                     {
                         "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
@@ -291,14 +328,6 @@ def test_profiler_save_and_load(data_context_with_taxi_data):
                         "reduce_scalar_metric": True,
                         "evaluation_parameter_builder_configs": None,
                         "json_serialize": True,
-                        "batch_request": {
-                            "datasource_name": "taxi_multibatch_datasource_other_possibility",
-                            "data_connector_name": "default_inferred_data_connector_name",
-                            "data_asset_name": "yellow_tripdata_sample_2018",
-                            "batch_spec_passthrough": None,
-                            "data_connector_query": {"index": -1},
-                            "limit": None,
-                        },
                     },
                 ],
                 "expectation_configuration_builders": [
@@ -310,7 +339,6 @@ def test_profiler_save_and_load(data_context_with_taxi_data):
                         "column": "$domain.domain_kwargs.column",
                         "validation_parameter_builder_configs": None,
                         "value": "$parameter.my_column_min.value[-1]",
-                        "batch_request": None,
                     },
                 ],
             },
@@ -330,7 +358,6 @@ def test_profiler_run_with_expectation_suite_arg(
     )
     domain_builder: DomainBuilder = ColumnDomainBuilder(
         include_column_name_suffixes=["_amount"],
-        batch_request=batch_request.to_json_dict(),
         data_context=context,
     )
     default_expectation_configuration_builder = DefaultExpectationConfigurationBuilder(
@@ -339,6 +366,7 @@ def test_profiler_run_with_expectation_suite_arg(
     )
     simple_rule: Rule = Rule(
         name="rule_with_no_variables_no_parameters",
+        variables=None,
         domain_builder=domain_builder,
         expectation_configuration_builders=[default_expectation_configuration_builder],
     )
@@ -367,7 +395,10 @@ def test_profiler_run_with_expectation_suite_arg(
     assert len(basic_expectation_suite.expectations) == 4
     assert basic_expectation_suite.expectations == existing_expectations
 
-    res: ExpectationSuite = my_rbp.run(expectation_suite=basic_expectation_suite)
+    my_rbp.run(batch_request=batch_request)
+    res: ExpectationSuite = my_rbp.get_expectation_suite(
+        expectation_suite=basic_expectation_suite
+    )
 
     assert id(res) == id(basic_expectation_suite)
     assert len(res.expectations) == 8
