@@ -12,13 +12,15 @@ from great_expectations.rule_based_profiler.domain_builder import ColumnDomainBu
 from great_expectations.rule_based_profiler.expectation_configuration_builder import (
     DefaultExpectationConfigurationBuilder,
 )
-from great_expectations.rule_based_profiler.rule import Rule
+from great_expectations.rule_based_profiler.rule import Rule, RuleOutput
 from great_expectations.rule_based_profiler.types import (
+    DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+    FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER,
     Domain,
     ParameterContainer,
     ParameterNode,
+    RuleState,
 )
-from tests.conftest import skip_if_python_below_minimum_version
 
 yaml = YAML()
 
@@ -31,8 +33,6 @@ ATOL: float = 5.0e-2
 
 @pytest.fixture
 def pandas_test_df():
-    skip_if_python_below_minimum_version()
-
     df: pd.DataFrame = pd.DataFrame(
         {
             "Age": pd.Series(
@@ -74,9 +74,8 @@ def pandas_test_df():
 # noinspection PyPep8Naming
 @pytest.fixture
 def table_Users_domain():
-    skip_if_python_below_minimum_version()
-
     return Domain(
+        rule_name="my_rule",
         domain_type=MetricDomainTypes.TABLE,
         domain_kwargs=None,
         details=None,
@@ -86,13 +85,11 @@ def table_Users_domain():
 # noinspection PyPep8Naming
 @pytest.fixture
 def column_Age_domain():
-    skip_if_python_below_minimum_version()
-
     return Domain(
+        rule_name="my_rule",
         domain_type=MetricDomainTypes.COLUMN,
         domain_kwargs={
             "column": "Age",
-            "batch_id": "c260e179bb1bc81d84bba72a8110d8e2",
         },
         details=None,
     )
@@ -101,13 +98,11 @@ def column_Age_domain():
 # noinspection PyPep8Naming
 @pytest.fixture
 def column_Date_domain():
-    skip_if_python_below_minimum_version()
-
     return Domain(
+        rule_name="my_rule",
         domain_type=MetricDomainTypes.COLUMN,
         domain_kwargs={
             "column": "Date",
-            "batch_id": "c260e179bb1bc81d84bba72a8110d8e2",
         },
         details=None,
     )
@@ -116,13 +111,42 @@ def column_Date_domain():
 # noinspection PyPep8Naming
 @pytest.fixture
 def column_Description_domain():
-    skip_if_python_below_minimum_version()
-
     return Domain(
+        rule_name="my_rule",
         domain_type=MetricDomainTypes.COLUMN,
         domain_kwargs={
             "column": "Description",
-            "batch_id": "c260e179bb1bc81d84bba72a8110d8e2",
+        },
+        details=None,
+    )
+
+
+# noinspection PyPep8Naming
+@pytest.fixture
+def column_pair_Age_Date_domain():
+    return Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN_PAIR,
+        domain_kwargs={
+            "column_A": "Age",
+            "column_B": "Date",
+        },
+        details=None,
+    )
+
+
+# noinspection PyPep8Naming
+@pytest.fixture
+def multi_column_Age_Date_Description_domain():
+    return Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.MULTICOLUMN,
+        domain_kwargs={
+            "column_list": [
+                "Age",
+                "Date",
+                "Description",
+            ],
         },
         details=None,
     )
@@ -130,8 +154,6 @@ def column_Description_domain():
 
 @pytest.fixture
 def single_part_name_parameter_container():
-    skip_if_python_below_minimum_version()
-
     return ParameterContainer(
         parameter_nodes={
             "mean": ParameterNode(
@@ -174,8 +196,6 @@ def multi_part_name_parameter_container():
     $parameter.weekly_taxi_fairs.mean_values.value[21]['monday']
     $parameter.weekly_taxi_fairs.mean_values.details
     """
-    skip_if_python_below_minimum_version()
-
     root_mean_node: ParameterNode = ParameterNode(
         {
             "mean": 6.5e-1,
@@ -358,8 +378,6 @@ def multi_part_name_parameter_container():
 
 @pytest.fixture
 def parameters_with_different_depth_level_values():
-    skip_if_python_below_minimum_version()
-
     parameter_values: Dict[str, Any] = {
         "$parameter.date_strings.yyyy_mm_dd_hh_mm_ss_tz_date_format.value": "%Y-%m-%d %H:%M:%S %Z",
         "$parameter.date_strings.yyyy_mm_dd_hh_mm_ss_tz_date_format.details": {
@@ -450,8 +468,6 @@ def parameters_with_different_depth_level_values():
 
 @pytest.fixture
 def variables_multi_part_name_parameter_container():
-    skip_if_python_below_minimum_version()
-
     variables_multi_part_name_parameter_node: ParameterNode = ParameterNode(
         {
             "false_positive_threshold": 1.0e-2,
@@ -470,27 +486,9 @@ def variables_multi_part_name_parameter_container():
     return variables
 
 
-@pytest.fixture
-def rule_without_parameters(
-    empty_data_context,
-):
-    skip_if_python_below_minimum_version()
-
-    rule: Rule = Rule(
-        name="rule_with_no_variables_no_parameters",
-        domain_builder=ColumnDomainBuilder(data_context=empty_data_context),
-        expectation_configuration_builders=[
-            DefaultExpectationConfigurationBuilder(
-                expectation_type="expect_my_validation"
-            )
-        ],
-    )
-    return rule
-
-
 # noinspection PyPep8Naming
 @pytest.fixture
-def rule_with_parameters(
+def rule_without_variables(
     empty_data_context,
     column_Age_domain,
     column_Date_domain,
@@ -498,31 +496,58 @@ def rule_with_parameters(
     single_part_name_parameter_container,
     multi_part_name_parameter_container,
 ):
-    skip_if_python_below_minimum_version()
-
     rule: Rule = Rule(
-        name="rule_with_parameters",
+        name="rule_without_variables",
+        variables=None,
         domain_builder=ColumnDomainBuilder(data_context=empty_data_context),
         expectation_configuration_builders=[
             DefaultExpectationConfigurationBuilder(
-                expectation_type="expect_my_validation"
-            )
+                expectation_type="expect_my_validation",
+                column=f"{DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}column",
+            ),
         ],
     )
-    rule._parameters = {
-        column_Age_domain.id: single_part_name_parameter_container,
-        column_Date_domain.id: multi_part_name_parameter_container,
-    }
     return rule
 
 
+# noinspection PyPep8Naming
+@pytest.fixture
+def rule_state_with_domains_and_parameters(
+    rule_without_variables,
+    column_Age_domain,
+    column_Date_domain,
+    single_part_name_parameter_container,
+    multi_part_name_parameter_container,
+):
+    rule_state: RuleState = RuleState(
+        rule=rule_without_variables,
+        domains=[
+            column_Age_domain,
+            column_Date_domain,
+        ],
+        parameters={
+            column_Age_domain.id: single_part_name_parameter_container,
+            column_Date_domain.id: multi_part_name_parameter_container,
+        },
+    )
+    return rule_state
+
+
+@pytest.fixture
+def rule_output_for_rule_state_with_domains_and_parameters(
+    rule_state_with_domains_and_parameters,
+):
+    rule_output: RuleOutput = RuleOutput(
+        rule_state=rule_state_with_domains_and_parameters
+    )
+    return rule_output
+
+
 @pytest.fixture
 def profiler_with_placeholder_args(
     empty_data_context,
     profiler_config_with_placeholder_args,
 ):
-    skip_if_python_below_minimum_version()
-
     profiler_config_dict: dict = profiler_config_with_placeholder_args.to_json_dict()
     profiler_config_dict.pop("class_name", None)
     profiler_config_dict.pop("module_name", None)
