@@ -10,7 +10,31 @@ from great_expectations.rule_based_profiler.domain_builder import DomainBuilder
 from great_expectations.rule_based_profiler.domain_builder.categorical_column_domain_builder import (
     CategoricalColumnDomainBuilder,
 )
-from great_expectations.rule_based_profiler.types import Domain
+from great_expectations.rule_based_profiler.types import (
+    INFERRED_SEMANTIC_TYPE_KEY,
+    Domain,
+    SemanticDomainTypes,
+)
+
+
+def test_instantiate_with_cardinality_limit_modes(
+    alice_columnar_table_single_batch_context,
+):
+    data_context: DataContext = alice_columnar_table_single_batch_context
+
+    batch_request: BatchRequest = BatchRequest(
+        datasource_name="alice_columnar_table_single_batch_datasource",
+        data_connector_name="alice_columnar_table_single_batch_data_connector",
+        data_asset_name="alice_columnar_table_single_batch_data_asset",
+    )
+
+    domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
+        exclude_column_name_suffixes="_id",
+        limit_mode=CategoricalColumnDomainBuilder.cardinality_limit_modes.VERY_FEW,
+        data_context=data_context,
+    )
+
+    domain_builder.get_domains(rule_name="my_rule", batch_request=batch_request)
 
 
 def test_single_batch_very_few_cardinality(alice_columnar_table_single_batch_context):
@@ -25,10 +49,11 @@ def test_single_batch_very_few_cardinality(alice_columnar_table_single_batch_con
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
         exclude_column_name_suffixes="_id",
         limit_mode="very_few",
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
 
     alice_all_column_names: List[str] = [
         "event_type",
@@ -41,6 +66,7 @@ def test_single_batch_very_few_cardinality(alice_columnar_table_single_batch_con
     column_name: str
     alice_all_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -49,6 +75,12 @@ def test_single_batch_very_few_cardinality(alice_columnar_table_single_batch_con
         for column_name in alice_all_column_names
     ]
     assert len(domains) == 5
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     assert domains == alice_all_column_domains
 
 
@@ -63,10 +95,11 @@ def test_single_batch_one_cardinality(alice_columnar_table_single_batch_context)
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
         limit_mode="ONE",
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
 
     alice_all_column_names: List[str] = [
         "user_agent",
@@ -75,6 +108,7 @@ def test_single_batch_one_cardinality(alice_columnar_table_single_batch_context)
     column_name: str
     alice_all_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -83,6 +117,12 @@ def test_single_batch_one_cardinality(alice_columnar_table_single_batch_context)
         for column_name in alice_all_column_names
     ]
     assert len(domains) == 1
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     assert domains == alice_all_column_domains
 
 
@@ -98,11 +138,11 @@ def test_unsupported_cardinality_limit(
     }
 
     with pytest.raises(ProfilerConfigurationError) as excinfo:
-        _: List[Domain] = CategoricalColumnDomainBuilder(
+        # noinspection PyUnusedLocal,PyArgumentList
+        domains: List[Domain] = CategoricalColumnDomainBuilder(
             limit_mode="&*#$&INVALID&*#$*&",
-            batch_request=batch_request,
             data_context=data_context,
-        ).get_domains()
+        ).get_domains(rule_name="my_rule", batch_request=batch_request)
 
     assert "specify a supported cardinality mode" in str(excinfo.value)
     assert "REL_1" in str(excinfo.value)
@@ -121,10 +161,10 @@ def test_unspecified_cardinality_limit(
     }
 
     with pytest.raises(ProfilerConfigurationError) as excinfo:
-        _: List[Domain] = CategoricalColumnDomainBuilder(
-            batch_request=batch_request,
-            data_context=data_context,
-        ).get_domains()
+        # noinspection PyUnusedLocal,PyArgumentList
+        domains: List[Domain] = CategoricalColumnDomainBuilder(
+            data_context=data_context
+        ).get_domains(rule_name="my_rule", batch_request=batch_request)
 
     assert "Please pass ONE of the following parameters" in str(excinfo.value)
     assert "you passed 0 parameters" in str(excinfo.value)
@@ -148,10 +188,11 @@ def test_excluded_columns_single_batch(alice_columnar_table_single_batch_context
             "event_ts",
             "server_ts",
         ],
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
 
     alice_all_column_names: List[str] = [
         "device_ts",
@@ -161,6 +202,7 @@ def test_excluded_columns_single_batch(alice_columnar_table_single_batch_context
     column_name: str
     alice_all_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -169,6 +211,12 @@ def test_excluded_columns_single_batch(alice_columnar_table_single_batch_context
         for column_name in alice_all_column_names
     ]
     assert len(domains) == 2
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     assert domains == alice_all_column_domains
 
 
@@ -184,10 +232,11 @@ def test_excluded_columns_empty_single_batch(alice_columnar_table_single_batch_c
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
         limit_mode="VERY_FEW",
         exclude_column_names=[],
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
 
     alice_all_column_names: List[str] = [
         "id",
@@ -202,6 +251,7 @@ def test_excluded_columns_empty_single_batch(alice_columnar_table_single_batch_c
     column_name: str
     alice_all_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -210,6 +260,12 @@ def test_excluded_columns_empty_single_batch(alice_columnar_table_single_batch_c
         for column_name in alice_all_column_names
     ]
     assert len(domains) == 7
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     assert domains == alice_all_column_domains
 
 
@@ -228,59 +284,108 @@ def test_multi_batch_very_few_cardinality(
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
         limit_mode="very_few",
-        batch_request=batch_request,
         data_context=data_context,
     )
-    observed_domains: List[Domain] = domain_builder.get_domains()
+    observed_domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
 
     expected_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "VendorID",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "VendorID": SemanticDomainTypes.NUMERIC,
+                },
+            },
         ),
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "passenger_count",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "passenger_count": SemanticDomainTypes.NUMERIC,
+                },
+            },
         ),
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "RatecodeID",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "RatecodeID": SemanticDomainTypes.NUMERIC,
+                },
+            },
         ),
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "store_and_fwd_flag",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "store_and_fwd_flag": SemanticDomainTypes.TEXT,
+                },
+            },
         ),
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "payment_type",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "payment_type": SemanticDomainTypes.NUMERIC,
+                }
+            },
         ),
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "mta_tax",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "mta_tax": SemanticDomainTypes.NUMERIC,
+                },
+            },
         ),
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "improvement_surcharge",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "improvement_surcharge": SemanticDomainTypes.NUMERIC,
+                },
+            },
         ),
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": "congestion_surcharge",
             },
+            details={
+                INFERRED_SEMANTIC_TYPE_KEY: {
+                    "congestion_surcharge": SemanticDomainTypes.NUMERIC,
+                },
+            },
         ),
     ]
 
@@ -303,10 +408,11 @@ def test_multi_batch_one_cardinality(
 
     domain_builder: DomainBuilder = CategoricalColumnDomainBuilder(
         limit_mode="ONE",
-        batch_request=batch_request,
         data_context=data_context,
     )
-    observed_domains: List[Domain] = domain_builder.get_domains()
+    observed_domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
 
     expected_domains: List[Domain] = []
 
