@@ -23,10 +23,17 @@ def test_column_values_unique_single_batch(alice_columnar_table_single_batch_con
         max_unexpected_values=0,
         max_unexpected_ratio=None,
         min_max_unexpected_values_proportion=9.75e-1,
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     domains = sorted(domains, key=lambda x: x.domain_kwargs["column"])
 
     alice_compliant_column_names: List[str] = [
@@ -41,6 +48,7 @@ def test_column_values_unique_single_batch(alice_columnar_table_single_batch_con
     column_name: str
     alice_expected_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -74,10 +82,17 @@ def test_column_values_nonnull_multi_batch_one_column_not_emitted(
         max_unexpected_values=0,
         max_unexpected_ratio=None,
         min_max_unexpected_values_proportion=9.75e-1,
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     domains = sorted(domains, key=lambda x: x.domain_kwargs["column"])
 
     bobby_compliant_column_names: List[str] = [
@@ -103,6 +118,7 @@ def test_column_values_nonnull_multi_batch_one_column_not_emitted(
     column_name: str
     bobby_expected_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -136,10 +152,17 @@ def test_column_values_nonnull_multi_batch_all_columns_emitted_loose_max_unexpec
         max_unexpected_values=4736,
         max_unexpected_ratio=None,
         min_max_unexpected_values_proportion=1.0,
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     domains = sorted(domains, key=lambda x: x.domain_kwargs["column"])
 
     bobby_compliant_column_names: List[str] = [
@@ -166,6 +189,7 @@ def test_column_values_nonnull_multi_batch_all_columns_emitted_loose_max_unexpec
     column_name: str
     bobby_expected_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -199,10 +223,17 @@ def test_column_values_nonnull_multi_batch_all_columns_emitted_loose_min_max_une
         max_unexpected_values=0,
         max_unexpected_ratio=None,
         min_max_unexpected_values_proportion=6.66e-1,
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     domains = sorted(domains, key=lambda x: x.domain_kwargs["column"])
 
     bobby_compliant_column_names: List[str] = [
@@ -229,6 +260,7 @@ def test_column_values_nonnull_multi_batch_all_columns_emitted_loose_min_max_une
     column_name: str
     bobby_expected_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -262,10 +294,17 @@ def test_column_values_nonnull_multi_batch_one_column_not_emitted_tight_max_unex
         max_unexpected_values=0,
         max_unexpected_ratio=0.0,
         min_max_unexpected_values_proportion=1.0,
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     domains = sorted(domains, key=lambda x: x.domain_kwargs["column"])
 
     bobby_compliant_column_names: List[str] = [
@@ -291,6 +330,7 @@ def test_column_values_nonnull_multi_batch_one_column_not_emitted_tight_max_unex
     column_name: str
     bobby_expected_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
@@ -324,10 +364,17 @@ def test_column_values_nonnull_multi_batch_all_columns_emitted_loose_max_unexpec
         max_unexpected_values=0,
         max_unexpected_ratio=5.58 - 1,
         min_max_unexpected_values_proportion=1.0,
-        batch_request=batch_request,
         data_context=data_context,
     )
-    domains: List[Domain] = domain_builder.get_domains()
+    domains: List[Domain] = domain_builder.get_domains(
+        rule_name="my_rule", batch_request=batch_request
+    )
+
+    # Unit Tests for "inferred_semantic_domain_type" are provided separately.
+    domain: Domain
+    for domain in domains:
+        domain.details = {}
+
     domains = sorted(domains, key=lambda x: x.domain_kwargs["column"])
 
     bobby_compliant_column_names: List[str] = [
@@ -354,6 +401,7 @@ def test_column_values_nonnull_multi_batch_all_columns_emitted_loose_max_unexpec
     column_name: str
     bobby_expected_column_domains: List[Domain] = [
         Domain(
+            rule_name="my_rule",
             domain_type=MetricDomainTypes.COLUMN,
             domain_kwargs={
                 "column": column_name,
