@@ -40,24 +40,30 @@ def test_meta_not_dict_exception(
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
 
     min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
     )
 
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
         domain=domain,
-        parameters={domain.id: parameter_container},
+        parameters=parameters,
     )
 
     condition = None
@@ -98,24 +104,30 @@ def test_condition_not_string_exception(
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
 
     min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
     )
 
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
         domain=domain,
-        parameters={domain.id: parameter_container},
+        parameters=parameters,
     )
 
     condition: dict = {"condition": "$variables.tolerance<0.8"}
@@ -155,23 +167,25 @@ def test_default_expectation_configuration_builder_alice_null_condition_paramete
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -192,7 +206,6 @@ def test_default_expectation_configuration_builder_alice_null_condition_paramete
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         parameters=parameters,
     )
@@ -215,9 +228,10 @@ def test_default_expectation_configuration_builder_alice_null_condition_paramete
 
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
-
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
@@ -234,7 +248,6 @@ def test_default_expectation_configuration_builder_alice_null_condition_paramete
             name="my_min_user_id",
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
-            batch_request=batch_request,
         )
     )
     validation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]] = [
@@ -246,16 +259,15 @@ def test_default_expectation_configuration_builder_alice_null_condition_paramete
         min_value=fully_qualified_parameter_name_for_value,
         max_value=max_user_id,
         validation_parameter_builder_configs=validation_parameter_builder_configs,
-        batch_request=batch_request,
         data_context=data_context,
     )
 
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     assert expectation_configuration.kwargs["min_value"] == 397433
@@ -280,23 +292,25 @@ def test_default_expectation_configuration_builder_alice_single_term_parameter_c
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -317,7 +331,6 @@ def test_default_expectation_configuration_builder_alice_single_term_parameter_c
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         parameters=parameters,
     )
@@ -344,24 +357,25 @@ def test_default_expectation_configuration_builder_alice_single_term_parameter_c
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -382,7 +396,6 @@ def test_default_expectation_configuration_builder_alice_single_term_parameter_c
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         parameters=parameters,
     )
@@ -409,26 +422,28 @@ def test_default_expectation_configuration_builder_alice_single_term_variable_co
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -449,7 +464,6 @@ def test_default_expectation_configuration_builder_alice_single_term_variable_co
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -477,26 +491,28 @@ def test_default_expectation_configuration_builder_alice_single_term_variable_co
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -517,7 +533,6 @@ def test_default_expectation_configuration_builder_alice_single_term_variable_co
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -545,26 +560,28 @@ def test_default_expectation_configuration_builder_alice_two_term_and_parameter_
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -585,7 +602,6 @@ def test_default_expectation_configuration_builder_alice_two_term_and_parameter_
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -613,26 +629,28 @@ def test_default_expectation_configuration_builder_alice_two_term_and_parameter_
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -653,7 +671,6 @@ def test_default_expectation_configuration_builder_alice_two_term_and_parameter_
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -681,26 +698,28 @@ def test_default_expectation_configuration_builder_alice_two_term_or_parameter_v
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -721,7 +740,6 @@ def test_default_expectation_configuration_builder_alice_two_term_or_parameter_v
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -749,26 +767,28 @@ def test_default_expectation_configuration_builder_alice_two_term_or_parameter_v
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -789,7 +809,6 @@ def test_default_expectation_configuration_builder_alice_two_term_or_parameter_v
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -817,26 +836,28 @@ def test_default_expectation_configuration_builder_alice_more_than_two_term_para
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999, "answer": 42}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -857,7 +878,6 @@ def test_default_expectation_configuration_builder_alice_more_than_two_term_para
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -885,26 +905,28 @@ def test_default_expectation_configuration_builder_alice_more_than_two_term_para
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999, "answer": 42}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -925,7 +947,6 @@ def test_default_expectation_configuration_builder_alice_more_than_two_term_para
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -953,26 +974,28 @@ def test_default_expectation_configuration_builder_alice_parentheses_parameter_v
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999, "answer": 42}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -993,7 +1016,6 @@ def test_default_expectation_configuration_builder_alice_parentheses_parameter_v
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
@@ -1021,26 +1043,28 @@ def test_default_expectation_configuration_builder_alice_parentheses_parameter_v
             metric_name="column.min",
             metric_domain_kwargs=metric_domain_kwargs,
             data_context=data_context,
-            batch_request=batch_request,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
-
-    min_user_id_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
-    )
-
     variables: ParameterContainer = build_parameter_container_for_variables(
         {"max_user_id": 999999999999, "answer": 42}
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
+    )
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
+    min_user_id_parameter.build_parameters(
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
+    )
+
     fully_qualified_parameter_name_for_value: str = "$parameter.my_min_user_id.value[0]"
     parameter_value: Any = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
@@ -1061,7 +1085,6 @@ def test_default_expectation_configuration_builder_alice_parentheses_parameter_v
     expectation_configuration: Optional[
         ExpectationConfiguration
     ] = default_expectation_configuration_builder.build_expectation_configuration(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
