@@ -12,11 +12,13 @@ from great_expectations.rule_based_profiler.helpers.util import (
 from great_expectations.rule_based_profiler.parameter_builder import (
     MeanUnexpectedMapMetricMultiBatchParameterBuilder,
     MetricMultiBatchParameterBuilder,
+    ParameterBuilder,
 )
 from great_expectations.rule_based_profiler.types import (
     DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
     Domain,
     ParameterContainer,
+    ParameterNode,
 )
 from tests.rule_based_profiler.conftest import ATOL, RTOL
 
@@ -28,7 +30,8 @@ def test_instantiation_mean_unexpected_map_metric_multi_batch_parameter_builder(
         bobby_columnar_table_multi_batch_deterministic_data_context
     )
 
-    _: MeanUnexpectedMapMetricMultiBatchParameterBuilder = (
+    # noinspection PyUnusedLocal
+    parameter_builder: ParameterBuilder = (
         MeanUnexpectedMapMetricMultiBatchParameterBuilder(
             name="my_name",
             map_metric_name="column_values.nonnull",
@@ -46,8 +49,8 @@ def test_instantiation_mean_unexpected_map_metric_multi_batch_parameter_builder_
     )
 
     with pytest.raises(TypeError) as excinfo:
-        # noinspection PyArgumentList
-        _: MeanUnexpectedMapMetricMultiBatchParameterBuilder = (
+        # noinspection PyUnusedLocal,PyArgumentList
+        parameter_builder: ParameterBuilder = (
             MeanUnexpectedMapMetricMultiBatchParameterBuilder(
                 name="my_name",
                 map_metric_name="column_values.nonnull",
@@ -61,8 +64,8 @@ def test_instantiation_mean_unexpected_map_metric_multi_batch_parameter_builder_
     )
 
     with pytest.raises(TypeError) as excinfo:
-        # noinspection PyArgumentList
-        _: MeanUnexpectedMapMetricMultiBatchParameterBuilder = (
+        # noinspection PyUnusedLocal,PyArgumentList
+        parameter_builder: ParameterBuilder = (
             MeanUnexpectedMapMetricMultiBatchParameterBuilder(
                 name="my_name",
                 total_count_parameter_builder_name="my_total_count",
@@ -99,8 +102,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
         data_context=data_context,
     )
     my_null_count_metric_multi_batch_parameter_builder: MetricMultiBatchParameterBuilder = MetricMultiBatchParameterBuilder(
@@ -113,62 +114,60 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
         data_context=data_context,
     )
 
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_passenger_count_values_not_null_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=None,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_passenger_count_values_not_null_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=None,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     metric_domain_kwargs: dict = {"column": "passenger_count"}
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-
     variables: Optional[ParameterContainer] = None
+
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
     my_total_count_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
     my_null_count_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     mean_unexpected_map_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     expected_parameter_value: float = 0.0
 
-    actual_parameter_value: Optional[
-        Any
-    ] = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         domain=domain,
         parameter_reference=mean_unexpected_map_metric_multi_batch_parameter_builder.fully_qualified_parameter_name,
         expected_return_type=None,
@@ -179,11 +178,11 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
     rtol: float = RTOL
     atol: float = 5.0e-1 * ATOL
     np.testing.assert_allclose(
-        actual=actual_parameter_value.value,
+        actual=parameter_node.value,
         desired=expected_parameter_value,
         rtol=rtol,
         atol=atol,
-        err_msg=f"Actual value of {actual_parameter_value.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(actual_parameter_value.value)} tolerance.",
+        err_msg=f"Actual value of {parameter_node.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(parameter_node.value)} tolerance.",
     )
 
 
@@ -212,8 +211,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
     my_null_count_metric_multi_batch_parameter_builder_config: ParameterBuilderConfig = ParameterBuilderConfig(
         module_name="great_expectations.rule_based_profiler.parameter_builder",
@@ -227,52 +224,50 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
 
     evaluation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]] = [
         my_total_count_metric_multi_batch_parameter_builder_config,
         my_null_count_metric_multi_batch_parameter_builder_config,
     ]
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_passenger_count_values_not_null_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_passenger_count_values_not_null_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     metric_domain_kwargs: dict = {"column": "passenger_count"}
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-
     variables: Optional[ParameterContainer] = None
+
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
     mean_unexpected_map_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     expected_parameter_value: float = 0.0
 
-    actual_parameter_value: Optional[
-        Any
-    ] = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         domain=domain,
         parameter_reference=mean_unexpected_map_metric_multi_batch_parameter_builder.fully_qualified_parameter_name,
         expected_return_type=None,
@@ -283,11 +278,11 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
     rtol: float = RTOL
     atol: float = 5.0e-1 * ATOL
     np.testing.assert_allclose(
-        actual=actual_parameter_value.value,
+        actual=parameter_node.value,
         desired=expected_parameter_value,
         rtol=rtol,
         atol=atol,
-        err_msg=f"Actual value of {actual_parameter_value.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(actual_parameter_value.value)} tolerance.",
+        err_msg=f"Actual value of {parameter_node.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(parameter_node.value)} tolerance.",
     )
 
 
@@ -316,8 +311,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
     my_null_count_metric_multi_batch_parameter_builder: MetricMultiBatchParameterBuilder = MetricMultiBatchParameterBuilder(
         name="my_null_count",
@@ -329,59 +322,57 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
         data_context=data_context,
     )
 
     evaluation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]] = [
         my_total_count_metric_multi_batch_parameter_builder_config,
     ]
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_passenger_count_values_not_null_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_passenger_count_values_not_null_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     metric_domain_kwargs: dict = {"column": "passenger_count"}
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-
     variables: Optional[ParameterContainer] = None
+
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
     my_null_count_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     mean_unexpected_map_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     expected_parameter_value: float = 0.0
 
-    actual_parameter_value: Optional[
-        Any
-    ] = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         domain=domain,
         parameter_reference=mean_unexpected_map_metric_multi_batch_parameter_builder.fully_qualified_parameter_name,
         expected_return_type=None,
@@ -392,11 +383,11 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_numeric_
     rtol: float = RTOL
     atol: float = 5.0e-1 * ATOL
     np.testing.assert_allclose(
-        actual=actual_parameter_value.value,
+        actual=parameter_node.value,
         desired=expected_parameter_value,
         rtol=rtol,
         atol=atol,
-        err_msg=f"Actual value of {actual_parameter_value.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(actual_parameter_value.value)} tolerance.",
+        err_msg=f"Actual value of {parameter_node.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(parameter_node.value)} tolerance.",
     )
 
 
@@ -423,8 +414,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
         data_context=data_context,
     )
     my_null_count_metric_multi_batch_parameter_builder: MetricMultiBatchParameterBuilder = MetricMultiBatchParameterBuilder(
@@ -437,62 +426,60 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
         data_context=data_context,
     )
 
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=None,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=None,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     metric_domain_kwargs: dict = {"column": "pickup_datetime"}
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-
     variables: Optional[ParameterContainer] = None
+
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
     my_total_count_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
     my_null_count_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     mean_unexpected_map_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     expected_parameter_value: float = 3.89e-3
 
-    actual_parameter_value: Optional[
-        Any
-    ] = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         domain=domain,
         parameter_reference=mean_unexpected_map_metric_multi_batch_parameter_builder.fully_qualified_parameter_name,
         expected_return_type=None,
@@ -503,11 +490,11 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
     rtol: float = RTOL
     atol: float = 5.0e-1 * ATOL
     np.testing.assert_allclose(
-        actual=actual_parameter_value.value,
+        actual=parameter_node.value,
         desired=expected_parameter_value,
         rtol=rtol,
         atol=atol,
-        err_msg=f"Actual value of {actual_parameter_value.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(actual_parameter_value.value)} tolerance.",
+        err_msg=f"Actual value of {parameter_node.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(parameter_node.value)} tolerance.",
     )
 
 
@@ -536,8 +523,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
     my_null_count_metric_multi_batch_parameter_builder_config: ParameterBuilderConfig = ParameterBuilderConfig(
         module_name="great_expectations.rule_based_profiler.parameter_builder",
@@ -551,52 +536,50 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
 
     evaluation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]] = [
         my_total_count_metric_multi_batch_parameter_builder_config,
         my_null_count_metric_multi_batch_parameter_builder_config,
     ]
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     metric_domain_kwargs: dict = {"column": "pickup_datetime"}
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-
     variables: Optional[ParameterContainer] = None
+
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
     mean_unexpected_map_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     expected_parameter_value: float = 3.89e-3
 
-    actual_parameter_value: Optional[
-        Any
-    ] = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         domain=domain,
         parameter_reference=mean_unexpected_map_metric_multi_batch_parameter_builder.fully_qualified_parameter_name,
         expected_return_type=None,
@@ -607,11 +590,11 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
     rtol: float = RTOL
     atol: float = 5.0e-1 * ATOL
     np.testing.assert_allclose(
-        actual=actual_parameter_value.value,
+        actual=parameter_node.value,
         desired=expected_parameter_value,
         rtol=rtol,
         atol=atol,
-        err_msg=f"Actual value of {actual_parameter_value.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(actual_parameter_value.value)} tolerance.",
+        err_msg=f"Actual value of {parameter_node.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(parameter_node.value)} tolerance.",
     )
 
 
@@ -638,8 +621,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
         data_context=data_context,
     )
     my_null_count_metric_multi_batch_parameter_builder_config: ParameterBuilderConfig = ParameterBuilderConfig(
@@ -654,58 +635,56 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
 
     evaluation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]] = [
         my_null_count_metric_multi_batch_parameter_builder_config,
     ]
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     metric_domain_kwargs: dict = {"column": "pickup_datetime"}
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-
     variables: Optional[ParameterContainer] = None
+
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     parameters: Dict[str, ParameterContainer] = {
         domain.id: parameter_container,
     }
 
     my_total_count_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     mean_unexpected_map_metric_multi_batch_parameter_builder.build_parameters(
-        parameter_container=parameter_container,
         domain=domain,
         variables=variables,
         parameters=parameters,
+        batch_request=batch_request,
     )
 
     expected_parameter_value: float = 3.89e-3
 
-    actual_parameter_value: Optional[
-        Any
-    ] = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         domain=domain,
         parameter_reference=mean_unexpected_map_metric_multi_batch_parameter_builder.fully_qualified_parameter_name,
         expected_return_type=None,
@@ -716,11 +695,11 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_datetime
     rtol: float = RTOL
     atol: float = 5.0e-1 * ATOL
     np.testing.assert_allclose(
-        actual=actual_parameter_value.value,
+        actual=parameter_node.value,
         desired=expected_parameter_value,
         rtol=rtol,
         atol=atol,
-        err_msg=f"Actual value of {actual_parameter_value.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(actual_parameter_value.value)} tolerance.",
+        err_msg=f"Actual value of {parameter_node.value} differs from expected value of {expected_parameter_value} by more than {atol + rtol * abs(parameter_node.value)} tolerance.",
     )
 
 
@@ -731,24 +710,18 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_check_se
         bobby_columnar_table_multi_batch_deterministic_data_context
     )
 
-    batch_request: dict = {
-        "datasource_name": "taxi_pandas",
-        "data_connector_name": "monthly",
-        "data_asset_name": "my_reports",
-    }
-
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=None,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=None,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     # Note: "evaluation_parameter_builder_configs" is not one of "ParameterBuilder" formal property attributes.
@@ -763,8 +736,8 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_check_se
         "null_count_parameter_builder_name",
         "metric_domain_kwargs",
         "metric_value_kwargs",
+        "evaluation_parameter_builder_configs",
         "json_serialize",
-        "batch_request",
     }
 
 
@@ -775,12 +748,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_check_se
         bobby_columnar_table_multi_batch_deterministic_data_context
     )
 
-    batch_request: dict = {
-        "datasource_name": "taxi_pandas",
-        "data_connector_name": "monthly",
-        "data_asset_name": "my_reports",
-    }
-
     my_total_count_metric_multi_batch_parameter_builder_config: ParameterBuilderConfig = ParameterBuilderConfig(
         module_name="great_expectations.rule_based_profiler.parameter_builder",
         class_name="MetricMultiBatchParameterBuilder",
@@ -793,8 +760,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_check_se
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
     my_null_count_metric_multi_batch_parameter_builder_config: ParameterBuilderConfig = ParameterBuilderConfig(
         module_name="great_expectations.rule_based_profiler.parameter_builder",
@@ -808,26 +773,24 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_check_se
         reduce_scalar_metric=True,
         evaluation_parameter_builder_configs=None,
         json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
     )
 
     evaluation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]] = [
         my_total_count_metric_multi_batch_parameter_builder_config,
         my_null_count_metric_multi_batch_parameter_builder_config,
     ]
-    mean_unexpected_map_metric_multi_batch_parameter_builder: MeanUnexpectedMapMetricMultiBatchParameterBuilder = MeanUnexpectedMapMetricMultiBatchParameterBuilder(
-        name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
-        map_metric_name="column_values.nonnull",
-        total_count_parameter_builder_name="my_total_count",
-        null_count_parameter_builder_name="my_null_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
-        json_serialize=False,
-        batch_list=None,
-        batch_request=batch_request,
-        data_context=data_context,
+    mean_unexpected_map_metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MeanUnexpectedMapMetricMultiBatchParameterBuilder(
+            name="my_pickup_datetime_count_values_unique_mean_unexpected_map_metric",
+            map_metric_name="column_values.nonnull",
+            total_count_parameter_builder_name="my_total_count",
+            null_count_parameter_builder_name="my_null_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
+            json_serialize=False,
+            data_context=data_context,
+        )
     )
 
     # Note: "evaluation_parameter_builder_configs" is not one of "ParameterBuilder" formal property attributes.
@@ -842,6 +805,6 @@ def test_mean_unexpected_map_metric_multi_batch_parameter_builder_bobby_check_se
         "null_count_parameter_builder_name",
         "metric_domain_kwargs",
         "metric_value_kwargs",
+        "evaluation_parameter_builder_configs",
         "json_serialize",
-        "batch_request",
     }
