@@ -1,6 +1,5 @@
-from typing import List, Set
+from typing import Dict, List, Set
 from unittest import mock
-from unittest.mock import MagicMock
 
 import pandas as pd
 import pytest
@@ -16,7 +15,11 @@ from great_expectations.core.id_dict import BatchSpec, IDDict
 from great_expectations.data_context import DataContext
 from great_expectations.execution_engine import PandasExecutionEngine
 from great_expectations.execution_engine.execution_engine import MetricDomainTypes
+from great_expectations.rule_based_profiler.helpers.util import (
+    get_parameter_value_and_validate_return_type,
+)
 from great_expectations.rule_based_profiler.parameter_builder import (
+    ParameterBuilder,
     RegexPatternStringParameterBuilder,
 )
 from great_expectations.rule_based_profiler.types import (
@@ -66,16 +69,16 @@ def test_regex_pattern_string_parameter_builder_instantiation_with_defaults(
     data_context: DataContext = mock_data_context
 
     candidate_regexes: Set[str] = {
-        r"/\d+/",  # whole number with 1 or more digits
-        r"/-?\d+/",  # negative whole numbers
-        r"/-?\d+(\.\d*)?/",  # decimal numbers with . (period) separator
-        r"/[A-Za-z0-9\.,;:!?()\"'%\-]+/",  # general text
-        r"^\s+/",  # leading space
-        r"\s+/$",  # trailing space
-        r"/https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#()?&//=]*)/",  # Matching URL (including http(s) protocol)
-        r"/<\/?(?:p|a|b|img)(?: \/)?>/",  # HTML tags
-        r"/(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}/",  # IPv4 IP address
-        r"/(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}/",  # IPv6 IP address,
+        r"\d+",  # whole number with 1 or more digits
+        r"-?\d+",  # negative whole numbers
+        r"-?\d+(\.\d*)?",  # decimal numbers with . (period) separator
+        r"[A-Za-z0-9\.,;:!?()\"'%\-]+",  # general text
+        r"^\s+",  # leading space
+        r"\s+$",  # trailing space
+        r"https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#()?&//=]*)",  #  Matching URL (including http(s) protocol)
+        r"<\/?(?:p|a|b|img)(?: \/)?>",  # HTML tags
+        r"(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}",  # IPv4 IP address
+        r"(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}",  # IPv6 IP address,
         r"\b[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}-[0-5][0-9a-fA-F]{3}-[089ab][0-9a-fA-F]{3}-\b[0-9a-fA-F]{12}\b ",  # UUID
     }
 
@@ -132,37 +135,44 @@ def test_regex_pattern_string_parameter_builder_alice(
         r"^\S{8}-\S{4}-\S{4}-\S{4}-\S{12}$",
     ]
 
-    regex_pattern_string_parameter: RegexPatternStringParameterBuilder = (
+    regex_pattern_string_parameter: ParameterBuilder = (
         RegexPatternStringParameterBuilder(
             name="my_regex_pattern_string_parameter_builder",
             metric_domain_kwargs=metric_domain_kwargs,
             candidate_regexes=candidate_regexes,
-            batch_request=batch_request,
             data_context=data_context,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
+
     assert parameter_container.parameter_nodes is None
 
     regex_pattern_string_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
     )
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder"
     )
     expected_value: dict = {
-        "value": [r"^\S{8}-\S{4}-\S{4}-\S{4}-\S{12}$"],
+        "value": r"^\S{8}-\S{4}-\S{4}-\S{4}-\S{12}$",
         "details": {
             "evaluated_regexes": {
                 r"^\S{8}-\S{4}-\S{4}-\S{4}-\S{12}$": 1.0,
-                r"^\d{1}$": 0,
-                r"^\d{2}$": 0,
+                r"^\d{1}$": 0.0,
+                r"^\d{2}$": 0.0,
             },
-            "threshold": 1.0,
+            "success_ratio": 1.0,
         },
     }
 
@@ -170,7 +180,7 @@ def test_regex_pattern_string_parameter_builder_alice(
         get_parameter_value_by_fully_qualified_parameter_name(
             fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
             domain=domain,
-            parameters={domain.id: parameter_container},
+            parameters=parameters,
         )
         == expected_value
     )
@@ -205,7 +215,6 @@ def test_regex_pattern_string_parameter_builder_bobby_multiple_matches(
             metric_domain_kwargs=metric_domain_kwargs,
             candidate_regexes=candidate_regexes,
             threshold=threshold,
-            batch_request=batch_request,
             data_context=data_context,
         )
     )
@@ -214,38 +223,44 @@ def test_regex_pattern_string_parameter_builder_bobby_multiple_matches(
     assert regex_parameter.candidate_regexes == candidate_regexes
     assert regex_parameter.threshold == 0.9
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
 
     assert parameter_container.parameter_nodes is None
 
     regex_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
     )
 
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder"
     )
     expected_value: dict = {
-        "value": [r"^[12]{1}$", r"^\d{1}$"],
+        "value": r"^\d{1}$",
         "details": {
             "evaluated_regexes": {
                 r"^\d{1}$": 1.0,
                 r"^[12]{1}$": 0.9941111111111111,
-                r"^\d{4}$": 0,
+                r"^\d{4}$": 0.0,
             },
-            "threshold": 0.9,
+            "success_ratio": 1.0,
         },
     }
 
     results = get_parameter_value_by_fully_qualified_parameter_name(
         fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
         domain=domain,
-        parameters={domain.id: parameter_container},
+        parameters=parameters,
     )
-
     assert results is not None
     assert sorted(results["value"]) == sorted(expected_value["value"])
     assert results["details"] == expected_value["details"]
@@ -272,47 +287,51 @@ def test_regex_pattern_string_parameter_builder_bobby_no_match(
     }
     threshold: float = 0.9
 
-    regex_parameter: RegexPatternStringParameterBuilder = (
-        RegexPatternStringParameterBuilder(
-            name="my_regex_pattern_string_parameter_builder",
-            metric_domain_kwargs=metric_domain_kwargs,
-            candidate_regexes=candidate_regexes,
-            threshold=threshold,
-            batch_request=batch_request,
-            data_context=data_context,
-        )
+    regex_parameter: ParameterBuilder = RegexPatternStringParameterBuilder(
+        name="my_regex_pattern_string_parameter_builder",
+        metric_domain_kwargs=metric_domain_kwargs,
+        candidate_regexes=candidate_regexes,
+        threshold=threshold,
+        data_context=data_context,
+    )
+    domain: Domain = Domain(
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
-    )
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
 
     assert parameter_container.parameter_nodes is None
 
     regex_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
     )
 
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder"
     )
     expected_value: dict = {
-        "value": [],
+        "value": "(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}",
         "details": {
             "evaluated_regexes": {
-                r"/\d+/": 0,
-                r"/-?\d+/": 0,
-                r"/-?\d+(\.\d*)?/": 0,
-                r"/[A-Za-z0-9\.,;:!?()\"'%\-]+/": 0,
-                r"^\s+/": 0,
-                r"\s+/$": 0,
-                r"/https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#()?&//=]*)/": 0,
-                r"/<\/?(?:p|a|b|img)(?: \/)?>/": 0,
-                r"/(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}/": 0,
-                r"/(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}/": 0,
-                r"\b[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}-[0-5][0-9a-fA-F]{3}-[089ab][0-9a-fA-F]{3}-\b[0-9a-fA-F]{12}\b ": 0,
+                r"\d+": 1.0,
+                r"-?\d+": 1.0,
+                r"-?\d+(\.\d*)?": 1.0,
+                r"[A-Za-z0-9\.,;:!?()\"'%\-]+": 1.0,
+                r"^\s+": 0.0,
+                r"\s+$": 0.0,
+                r"https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#()?&//=]*)": 0.0,
+                r"<\/?(?:p|a|b|img)(?: \/)?>": 0.0,
+                r"(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}": 0.0,
+                r"(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}": 1.0,
+                r"\b[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}-[0-5][0-9a-fA-F]{3}-[089ab][0-9a-fA-F]{3}-\b[0-9a-fA-F]{12}\b ": 0.0,
             },
-            "threshold": 0.9,
+            "success_ratio": 1.0,
         },
     }
 
@@ -320,7 +339,7 @@ def test_regex_pattern_string_parameter_builder_bobby_no_match(
         get_parameter_value_by_fully_qualified_parameter_name(
             fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
             domain=domain,
-            parameters={domain.id: parameter_container},
+            parameters=parameters,
         )
         == expected_value
     )
@@ -340,28 +359,35 @@ def test_regex_wrong_domain(mock_data_context: mock.MagicMock, batch_fixture: Ba
     metric_domain_kwargs: dict = {"column": "c"}
     candidate_regexes: List[str] = [r"^\d{1}$"]
 
-    regex_pattern_string_parameter_builder: RegexPatternStringParameterBuilder = (
+    regex_pattern_string_parameter_builder: ParameterBuilder = (
         RegexPatternStringParameterBuilder(
             name="my_regex_pattern_string_parameter_builder",
             metric_domain_kwargs=metric_domain_kwargs,
             candidate_regexes=candidate_regexes,
-            batch_list=[batch],
             data_context=data_context,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
+
     with pytest.raises(ge_exceptions.ProfilerExecutionError) as e:
         regex_pattern_string_parameter_builder.build_parameters(
-            parameter_container=parameter_container, domain=domain
+            domain=domain,
+            parameters=parameters,
+            batch_list=[batch],
         )
 
     assert (
         e.value.message
-        == "column_values.nonnull.count was not found in the resolved Metrics for ParameterBuilder."
+        == "Result of metric computations for RegexPatternStringParameterBuilder is empty."
     )
 
 
@@ -380,42 +406,59 @@ def test_regex_single_candidate(
     metric_domain_kwargs: dict = {"column": "b"}
     candidate_regexes: List[str] = [r"^\d{1}$"]
 
-    regex_pattern_string_parameter_builder: RegexPatternStringParameterBuilder = (
+    regex_pattern_string_parameter_builder: ParameterBuilder = (
         RegexPatternStringParameterBuilder(
             name="my_regex_pattern_string_parameter_builder",
             metric_domain_kwargs=metric_domain_kwargs,
             candidate_regexes=candidate_regexes,
-            batch_list=[batch],
             data_context=data_context,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
+
     assert parameter_container.parameter_nodes is None
 
     regex_pattern_string_parameter_builder.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_list=[batch],
     )
     fully_qualified_parameter_name_for_value: str = (
-        "$parameter.my_regex_pattern_string_parameter_builder"
+        "$parameter.my_regex_pattern_string_parameter_builder.value"
     )
-    expected_value: dict = {
-        "details": {"evaluated_regexes": {"^\\d{1}$": 1.0}, "threshold": 1.0},
-        "value": ["^\\d{1}$"],
-    }
-
+    expected_value: str = "^\\d{1}$"
     assert (
-        get_parameter_value_by_fully_qualified_parameter_name(
-            fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
+        get_parameter_value_and_validate_return_type(
+            parameter_reference=fully_qualified_parameter_name_for_value,
+            expected_return_type=str,
             domain=domain,
-            parameters={domain.id: parameter_container},
+            parameters=parameters,
         )
         == expected_value
     )
 
+    fully_qualified_parameter_name_for_meta: str = (
+        "$parameter.my_regex_pattern_string_parameter_builder.details"
+    )
+    expected_meta: dict = {"evaluated_regexes": {"^\\d{1}$": 1.0}, "success_ratio": 1.0}
+
+    meta: dict = get_parameter_value_and_validate_return_type(
+        parameter_reference=fully_qualified_parameter_name_for_meta,
+        expected_return_type=dict,
+        domain=domain,
+        parameters=parameters,
+    )
+    assert meta == expected_meta
+
 
 @mock.patch("great_expectations.data_context.data_context.DataContext")
 def test_regex_two_candidates(mock_data_context: mock.MagicMock, batch_fixture: Batch):
@@ -430,41 +473,58 @@ def test_regex_two_candidates(mock_data_context: mock.MagicMock, batch_fixture:
     metric_domain_kwargs: dict = {"column": "b"}
     candidate_regexes: List[str] = [r"^\d{1}$", r"^\d{3}$"]
 
-    regex_pattern_string_parameter_builder: RegexPatternStringParameterBuilder = (
+    regex_pattern_string_parameter_builder: ParameterBuilder = (
         RegexPatternStringParameterBuilder(
             name="my_regex_pattern_string_parameter_builder",
             metric_domain_kwargs=metric_domain_kwargs,
             candidate_regexes=candidate_regexes,
-            batch_list=[batch],
             data_context=data_context,
         )
     )
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
+
     assert parameter_container.parameter_nodes is None
 
     regex_pattern_string_parameter_builder.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_list=[batch],
     )
     fully_qualified_parameter_name_for_value: str = (
-        "$parameter.my_regex_pattern_string_parameter_builder"
+        "$parameter.my_regex_pattern_string_parameter_builder.value"
     )
-    expected_value: dict = {
-        "details": {
-            "evaluated_regexes": {"^\\d{1}$": 1.0, "^\\d{3}$": 0.0},
-            "threshold": 1.0,
-        },
-        "value": ["^\\d{1}$"],
-    }
+
+    expected_value: str = "^\\d{1}$"
 
     assert (
-        get_parameter_value_by_fully_qualified_parameter_name(
-            fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
+        get_parameter_value_and_validate_return_type(
+            parameter_reference=fully_qualified_parameter_name_for_value,
             domain=domain,
-            parameters={domain.id: parameter_container},
+            parameters=parameters,
         )
         == expected_value
     )
+    fully_qualified_parameter_name_for_meta: str = (
+        "$parameter.my_regex_pattern_string_parameter_builder.details"
+    )
+    expected_meta: dict = {
+        "evaluated_regexes": {"^\\d{1}$": 1.0, "^\\d{3}$": 0.0},
+        "success_ratio": 1.0,
+    }
+    meta: dict = get_parameter_value_and_validate_return_type(
+        parameter_reference=fully_qualified_parameter_name_for_meta,
+        expected_return_type=dict,
+        domain=domain,
+        parameters=parameters,
+    )
+
+    assert meta == expected_meta
