@@ -1,4 +1,4 @@
-from typing import Set
+from typing import Dict
 
 import pytest
 
@@ -9,74 +9,17 @@ from great_expectations.rule_based_profiler.helpers.util import (
     get_parameter_value_and_validate_return_type,
 )
 from great_expectations.rule_based_profiler.parameter_builder import (
+    ParameterBuilder,
     SimpleDateFormatStringParameterBuilder,
 )
 from great_expectations.rule_based_profiler.parameter_builder.simple_date_format_string_parameter_builder import (
     DEFAULT_CANDIDATE_STRINGS,
 )
-from great_expectations.rule_based_profiler.types import Domain, ParameterContainer
-
-DEFAULT_CANDIDATE_STRINGS: Set[str] = {
-    "%H:%M:%S",
-    "%H:%M:%S,%f",
-    "%H:%M:%S.%f",
-    "%Y %b %d %H:%M:%S.%f",
-    "%Y %b %d %H:%M:%S.%f %Z",
-    "%Y %b %d %H:%M:%S.%f*%Z",
-    "%Y%m%d %H:%M:%S.%f",
-    "%Y-%m-%d",
-    "%Y-%m-%d %H:%M:%S",
-    "%Y-%m-%d %H:%M:%S %z",
-    "%Y-%m-%d %H:%M:%S%z",
-    "%Y-%m-%d %H:%M:%S,%f",
-    "%Y-%m-%d %H:%M:%S,%f%z",
-    "%Y-%m-%d %H:%M:%S.%f",
-    "%Y-%m-%d %H:%M:%S.%f%z",
-    "%Y-%m-%d'T'%H:%M:%S",
-    "%Y-%m-%d'T'%H:%M:%S%z",
-    "%Y-%m-%d'T'%H:%M:%S'%z'",
-    "%Y-%m-%d'T'%H:%M:%S.%f",
-    "%Y-%m-%d'T'%H:%M:%S.%f'%z'",
-    "%Y-%m-%d*%H:%M:%S",
-    "%Y-%m-%d*%H:%M:%S:%f",
-    "%Y-%m-%dT%z",
-    "%Y/%m/%d",
-    "%Y/%m/%d*%H:%M:%S",
-    "%b %d %H:%M:%S",
-    "%b %d %H:%M:%S %Y",
-    "%b %d %H:%M:%S %z",
-    "%b %d %H:%M:%S %z %Y",
-    "%b %d %Y %H:%M:%S",
-    "%b %d, %Y %H:%M:%S %p",
-    "%d %b %Y %H:%M:%S",
-    "%d %b %Y %H:%M:%S*%f",
-    "%d-%b-%Y %H:%M:%S",
-    "%d-%b-%Y %H:%M:%S.%f",
-    "%d-%m-%Y",
-    "%d/%b %H:%M:%S,%f",
-    "%d/%b/%Y %H:%M:%S",
-    "%d/%b/%Y:%H:%M:%S",
-    "%d/%b/%Y:%H:%M:%S %z",
-    "%d/%m/%Y",
-    "%m%d_%H:%M:%S",
-    "%m%d_%H:%M:%S.%f",
-    "%m-%d-%Y",
-    "%m/%d/%Y",
-    "%m/%d/%Y %H:%M:%S %p",
-    "%m/%d/%Y %H:%M:%S %p:%f",
-    "%m/%d/%Y %H:%M:%S %z",
-    "%m/%d/%Y*%H:%M:%S",
-    "%m/%d/%Y*%H:%M:%S*%f",
-    "%m/%d/%y %H:%M:%S %z",
-    "%m/%d/%y*%H:%M:%S",
-    "%y%m%d %H:%M:%S",
-    "%y-%m-%d",
-    "%y-%m-%d %H:%M:%S",
-    "%y-%m-%d %H:%M:%S,%f",
-    "%y-%m-%d %H:%M:%S,%f %z",
-    "%y/%m/%d",
-    "%y/%m/%d %H:%M:%S",
-}
+from great_expectations.rule_based_profiler.types import (
+    Domain,
+    ParameterContainer,
+    ParameterNode,
+)
 
 
 def test_simple_date_format_parameter_builder_instantiation(
@@ -100,23 +43,28 @@ def test_simple_date_format_parameter_builder_zero_batch_id_error(
 ):
     data_context: DataContext = alice_columnar_table_single_batch_context
 
-    date_format_string_parameter: SimpleDateFormatStringParameterBuilder = (
+    date_format_string_parameter: ParameterBuilder = (
         SimpleDateFormatStringParameterBuilder(
             name="my_simple_date_format_string_parameter_builder",
             data_context=data_context,
         )
     )
+
+    domain: Domain = Domain(rule_name="my_rule", domain_type=MetricDomainTypes.COLUMN)
     parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
-    domain: Domain = Domain(domain_type=MetricDomainTypes.COLUMN)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
 
     with pytest.raises(ge_exceptions.ProfilerExecutionError) as e:
         date_format_string_parameter.build_parameters(
-            parameter_container=parameter_container, domain=domain
+            domain=domain,
+            parameters=parameters,
         )
 
     assert (
         str(e.value)
-        == "Utilizing a SimpleDateFormatStringParameterBuilder requires a non-empty list of batch identifiers."
+        == "Utilizing a SimpleDateFormatStringParameterBuilder requires a non-empty list of Batch identifiers."
     )
 
 
@@ -137,7 +85,6 @@ def test_simple_date_format_parameter_builder_alice(
         SimpleDateFormatStringParameterBuilder(
             name="my_date_format",
             metric_domain_kwargs=metric_domain_kwargs,
-            batch_request=batch_request,
             data_context=data_context,
         )
     )
@@ -145,15 +92,22 @@ def test_simple_date_format_parameter_builder_alice(
     assert date_format_string_parameter.candidate_strings == DEFAULT_CANDIDATE_STRINGS
     assert date_format_string_parameter._threshold == 1.0
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
 
     assert parameter_container.parameter_nodes is None
 
     date_format_string_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
     )
 
     # noinspection PyTypeChecker
@@ -164,18 +118,78 @@ def test_simple_date_format_parameter_builder_alice(
         "value": "%Y-%m-%d %H:%M:%S",
         "details": {
             "success_ratio": 1.0,
-            "candidate_strings": sorted(DEFAULT_CANDIDATE_STRINGS),
+            "candidate_strings": {
+                "%Y-%m-%d %H:%M:%S": 1.0,
+                "%y/%m/%d %H:%M:%S": 0.0,
+                "%y/%m/%d": 0.0,
+                "%y-%m-%d %H:%M:%S,%f %z": 0.0,
+                "%y-%m-%d %H:%M:%S,%f": 0.0,
+                "%y-%m-%d %H:%M:%S": 0.0,
+                "%y-%m-%d": 0.0,
+                "%y%m%d %H:%M:%S": 0.0,
+                "%m/%d/%y*%H:%M:%S": 0.0,
+                "%m/%d/%y %H:%M:%S %z": 0.0,
+                "%m/%d/%Y*%H:%M:%S*%f": 0.0,
+                "%m/%d/%Y*%H:%M:%S": 0.0,
+                "%m/%d/%Y %H:%M:%S %z": 0.0,
+                "%m/%d/%Y %H:%M:%S %p:%f": 0.0,
+                "%m/%d/%Y %H:%M:%S %p": 0.0,
+                "%m/%d/%Y": 0.0,
+                "%m-%d-%Y": 0.0,
+                "%m%d_%H:%M:%S.%f": 0.0,
+                "%m%d_%H:%M:%S": 0.0,
+                "%d/%m/%Y": 0.0,
+                "%d/%b/%Y:%H:%M:%S %z": 0.0,
+                "%d/%b/%Y:%H:%M:%S": 0.0,
+                "%d/%b/%Y %H:%M:%S": 0.0,
+                "%d/%b %H:%M:%S,%f": 0.0,
+                "%d-%m-%Y": 0.0,
+                "%d-%b-%Y %H:%M:%S.%f": 0.0,
+                "%d-%b-%Y %H:%M:%S": 0.0,
+                "%d %b %Y %H:%M:%S*%f": 0.0,
+                "%d %b %Y %H:%M:%S": 0.0,
+                "%b %d, %Y %H:%M:%S %p": 0.0,
+                "%b %d %Y %H:%M:%S": 0.0,
+                "%b %d %H:%M:%S %z %Y": 0.0,
+                "%b %d %H:%M:%S %z": 0.0,
+                "%b %d %H:%M:%S %Y": 0.0,
+                "%b %d %H:%M:%S": 0.0,
+                "%Y/%m/%d*%H:%M:%S": 0.0,
+                "%Y/%m/%d": 0.0,
+                "%Y-%m-%dT%z": 0.0,
+                "%Y-%m-%d*%H:%M:%S:%f": 0.0,
+                "%Y-%m-%d*%H:%M:%S": 0.0,
+                "%Y-%m-%d'T'%H:%M:%S.%f'%z'": 0.0,
+                "%Y-%m-%d'T'%H:%M:%S.%f": 0.0,
+                "%Y-%m-%d'T'%H:%M:%S'%z'": 0.0,
+                "%Y-%m-%d'T'%H:%M:%S%z": 0.0,
+                "%Y-%m-%d'T'%H:%M:%S": 0.0,
+                "%Y-%m-%d %H:%M:%S.%f%z": 0.0,
+                "%Y-%m-%d %H:%M:%S.%f": 0.0,
+                "%Y-%m-%d %H:%M:%S,%f%z": 0.0,
+                "%Y-%m-%d %H:%M:%S,%f": 0.0,
+                "%Y-%m-%d %H:%M:%S%z": 0.0,
+                "%Y-%m-%d %H:%M:%S %z": 0.0,
+                "%Y-%m-%d": 0.0,
+                "%Y%m%d %H:%M:%S.%f": 0.0,
+                "%Y %b %d %H:%M:%S.%f*%Z": 0.0,
+                "%Y %b %d %H:%M:%S.%f %Z": 0.0,
+                "%Y %b %d %H:%M:%S.%f": 0.0,
+                "%H:%M:%S.%f": 0.0,
+                "%H:%M:%S,%f": 0.0,
+                "%H:%M:%S": 0.0,
+            },
         },
     }
 
-    actual_value: dict = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         parameter_reference=fully_qualified_parameter_name_for_value,
         expected_return_type=dict,
         domain=domain,
-        parameters={domain.id: parameter_container},
+        parameters=parameters,
     )
 
-    assert actual_value == expected_value
+    assert parameter_node == expected_value
 
 
 def test_simple_date_format_parameter_builder_bobby(
@@ -203,7 +217,6 @@ def test_simple_date_format_parameter_builder_bobby(
             metric_domain_kwargs=metric_domain_kwargs,
             candidate_strings=candidate_strings,
             threshold=threshold,
-            batch_request=batch_request,
             data_context=data_context,
         )
     )
@@ -211,15 +224,22 @@ def test_simple_date_format_parameter_builder_bobby(
     assert date_format_string_parameter._candidate_strings == set(candidate_strings)
     assert date_format_string_parameter._threshold == 0.9
 
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
     domain: Domain = Domain(
-        domain_type=MetricDomainTypes.COLUMN, domain_kwargs=metric_domain_kwargs
+        rule_name="my_rule",
+        domain_type=MetricDomainTypes.COLUMN,
+        domain_kwargs=metric_domain_kwargs,
     )
+    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameters: Dict[str, ParameterContainer] = {
+        domain.id: parameter_container,
+    }
 
     assert parameter_container.parameter_nodes is None
 
     date_format_string_parameter.build_parameters(
-        parameter_container=parameter_container, domain=domain
+        domain=domain,
+        parameters=parameters,
+        batch_request=batch_request,
     )
 
     assert (
@@ -232,26 +252,26 @@ def test_simple_date_format_parameter_builder_bobby(
     )
     expected_value: str = "%Y-%m-%d %H:%M:%S"
 
-    actual_value: str = get_parameter_value_and_validate_return_type(
+    parameter_node: ParameterNode = get_parameter_value_and_validate_return_type(
         parameter_reference=fully_qualified_parameter_name_for_value,
         expected_return_type=str,
         domain=domain,
-        parameters={domain.id: parameter_container},
+        parameters=parameters,
     )
 
-    assert actual_value == expected_value
+    assert parameter_node == expected_value
 
     fully_qualified_parameter_name_for_meta: str = (
         "$parameter.my_simple_date_format_string_parameter_builder.details"
     )
     expected_meta: dict = {
         "success_ratio": 1.0,
-        "candidate_strings": candidate_strings,
+        "candidate_strings": {"%Y-%m-%d": 0.0, "%Y-%m-%d %H:%M:%S": 1.0},
     }
     meta: dict = get_parameter_value_and_validate_return_type(
         parameter_reference=fully_qualified_parameter_name_for_meta,
         expected_return_type=dict,
         domain=domain,
-        parameters={domain.id: parameter_container},
+        parameters=parameters,
     )
     assert meta == expected_meta
