@@ -1,9 +1,11 @@
 import logging
 import os
 import uuid
+import warnings
 from contextlib import contextmanager
+from dataclasses import dataclass
 from pathlib import Path
-from typing import Generator, List, Union, cast
+from typing import Any, Generator, List, Optional, Set, Union, cast
 
 import numpy as np
 import pandas as pd
@@ -25,7 +27,11 @@ from great_expectations.data_context.store.util import (
     save_config_to_store_backend,
 )
 from great_expectations.data_context.types.base import BaseYamlConfig, CheckpointConfig
-from great_expectations.data_context.util import build_store_from_config
+from great_expectations.data_context.util import (
+    build_store_from_config,
+    instantiate_class_from_config,
+)
+from great_expectations.execution_engine import SqlAlchemyExecutionEngine
 
 logger = logging.getLogger(__name__)
 
@@ -440,20 +446,149 @@ def delete_config_from_filesystem(
     )
 
 
-def load_data_into_test_database(
-    table_name: str,
-    csv_path: str,
-    connection_string: str,
+def get_snowflake_connection_url() -> str:
+    """Get snowflake connection url from environment variables.
+
+    Returns:
+        String of the snowflake connection url.
+    """
+    sfAccount = os.environ.get("SNOWFLAKE_ACCOUNT")
+    sfUser = os.environ.get("SNOWFLAKE_USER")
+    sfPswd = os.environ.get("SNOWFLAKE_PW")
+    sfDatabase = os.environ.get("SNOWFLAKE_DATABASE")
+    sfSchema = os.environ.get("SNOWFLAKE_SCHEMA")
+    sfWarehouse = os.environ.get("SNOWFLAKE_WAREHOUSE")
+
+    return f"snowflake://{sfUser}:{sfPswd}@{sfAccount}/{sfDatabase}/{sfSchema}?warehouse={sfWarehouse}"
+
+
+def get_bigquery_table_prefix() -> str:
+    """Get table_prefix that will be used by the BigQuery client in loading a BigQuery table from DataFrame.
+
+    Reference link
+        https://cloud.google.com/bigquery/docs/samples/bigquery-load-table-dataframe
+
+    Returns:
+        String of table prefix, which is the gcp_project and dataset concatenated by a "."
+    """
+    gcp_project = os.environ.get("GE_TEST_GCP_PROJECT")
+    if not gcp_project:
+        raise ValueError(
+            "Environment Variable GE_TEST_GCP_PROJECT is required to run BigQuery integration tests"
+        )
+    bigquery_dataset = os.environ.get("GE_TEST_BIGQUERY_DATASET", "test_ci")
+    return f"""{gcp_project}.{bigquery_dataset}"""
+
+
+def get_bigquery_connection_url() -> str:
+    """Get bigquery connection url from environment variables.
+
+    Note: dataset defaults to "demo" if not set.
+
+    Returns:
+        String of the bigquery connection url.
+    """
+    gcp_project = os.environ.get("GE_TEST_GCP_PROJECT")
+    if not gcp_project:
+        raise ValueError(
+            "Environment Variable GE_TEST_GCP_PROJECT is required to run BigQuery integration tests"
+        )
+    bigquery_dataset = os.environ.get("GE_TEST_BIGQUERY_DATASET", "demo")
+
+    return f"bigquery://{gcp_project}/{bigquery_dataset}"
+
+
+@dataclass
+class LoadedTable:
+    """Output of loading a table via load_data_into_test_database."""
+
+    table_name: str
+    inserted_dataframe: pd.DataFrame
+
+
+def load_and_concatenate_csvs(
+    csv_paths: List[str],
     load_full_dataset: bool = False,
-) -> None:
-    """
-    Utility method that is used in loading test data into databases that can be accessed through SqlAlchemy.
-    This includes local Dockerized DBs like postgres, but also cloud-dbs like BigQuery and Redshift.
+    convert_column_names_to_datetime: Optional[List[str]] = None,
+) -> pd.DataFrame:
+    """Utility method that is used in loading test data into a pandas dataframe.
+
+    It includes several parameters used to describe the output data.
+
+    Args:
+        csv_paths: list of paths of csvs to write, can be a single path. These should all be the same shape.
+        load_full_dataset: if False, load only the first 10 rows.
+        convert_column_names_to_datetime: List of column names to convert to datetime before writing to db.
+
+    Returns:
+        A pandas dataframe concatenating data loaded from all csvs.
     """
+
+    if convert_column_names_to_datetime is None:
+        convert_column_names_to_datetime = []
+
     import pandas as pd
 
-    connection = None
+    dfs: List[pd.DataFrame] = []
+    for csv_path in csv_paths:
+        df = pd.read_csv(csv_path)
+        for column_name_to_convert in convert_column_names_to_datetime:
+            df[column_name_to_convert] = pd.to_datetime(df[column_name_to_convert])
+        if not load_full_dataset:
+            # Improving test performance by only loading the first 10 rows of our test data into the db
+            df = df.head(10)
 
+        dfs.append(df)
+
+    all_dfs_concatenated: pd.DataFrame = pd.concat(dfs)
+
+    return all_dfs_concatenated
+
+
+def load_data_into_test_database(
+    table_name: str,
+    connection_string: str,
+    csv_path: Optional[str] = None,
+    csv_paths: Optional[List[str]] = None,
+    load_full_dataset: bool = False,
+    convert_colnames_to_datetime: Optional[List[str]] = None,
+    random_table_suffix: bool = False,
+    to_sql_method: Optional[str] = None,
+) -> LoadedTable:
+    """Utility method that is used in loading test data into databases that can be accessed through SqlAlchemy.
+
+    This includes local Dockerized DBs like postgres, but also cloud-dbs like BigQuery and Redshift.
+
+    Args:
+        table_name: name of the table to write to.
+        connection_string: used to connect to the database.
+        csv_path: path of a single csv to write.
+        csv_paths: list of paths of csvs to write.
+        load_full_dataset: if False, load only the first 10 rows.
+        convert_colnames_to_datetime: List of column names to convert to datetime before writing to db.
+        random_table_suffix: If true, add 8 random characters to the table suffix and remove other tables with the
+            same prefix.
+        to_sql_method: Method to pass to method param of pd.to_sql()
+
+    Returns:
+        LoadedTable which for convenience, contains the pandas dataframe that was used to load the data.
+    """
+    if csv_path and csv_paths:
+        csv_paths.append(csv_path)
+    elif csv_path and not csv_paths:
+        csv_paths = [csv_path]
+
+    all_dfs_concatenated: pd.DataFrame = load_and_concatenate_csvs(
+        csv_paths, load_full_dataset, convert_colnames_to_datetime
+    )
+
+    if random_table_suffix:
+        table_name: str = f"{table_name}_{str(uuid.uuid4())[:8]}"
+
+    return_value: LoadedTable = LoadedTable(
+        table_name=table_name, inserted_dataframe=all_dfs_concatenated
+    )
+    connection = None
     if sa:
         engine = sa.create_engine(connection_string)
     else:
@@ -461,25 +596,111 @@ def load_data_into_test_database(
             "Attempting to load data in to tests SqlAlchemy database, but unable to load SqlAlchemy context; "
             "install optional sqlalchemy dependency for support."
         )
-        return
-    try:
-        connection = engine.connect()
+        return return_value
+    if engine.dialect.name.lower() == "bigquery":
+        # bigquery is handled in a special way
+        load_data_into_test_bigquery_database_with_bigquery_client(
+            dataframe=all_dfs_concatenated, table_name=table_name
+        )
+        return return_value
+    else:
+        try:
+            connection = engine.connect()
+            print(f"Dropping table {table_name}")
+            connection.execute(f"DROP TABLE IF EXISTS {table_name}")
+            print(f"Creating table {table_name} and adding data from {csv_paths}")
+            all_dfs_concatenated.to_sql(
+                name=table_name,
+                con=engine,
+                index=False,
+                if_exists="append",
+                method=to_sql_method,
+            )
+            return return_value
+        except SQLAlchemyError as e:
+            logger.error(
+                """Docs integration tests encountered an error while loading test-data into test-database."""
+            )
+            raise
+        finally:
+            connection.close()
+            engine.dispose()
+
+
+def load_data_into_test_bigquery_database_with_bigquery_client(
+    dataframe: pd.DataFrame, table_name: str
+) -> None:
+    """
+    Loads dataframe into bigquery table using BigQuery client. Follows pattern specified in the GCP documentation here:
+        - https://cloud.google.com/bigquery/docs/samples/bigquery-load-table-dataframe
+    Args:
+        dataframe (pd.DataFrame): DataFrame to load
+        table_name (str): table to load DataFrame to. Prefix containing project and dataset are loaded
+                        by helper function.
+    """
+    prefix: str = get_bigquery_table_prefix()
+    table_id: str = f"""{prefix}.{table_name}"""
+    from google.cloud import bigquery
+
+    gcp_project: Optional[str] = os.environ.get("GE_TEST_GCP_PROJECT")
+    if not gcp_project:
+        raise ValueError(
+            "Environment Variable GE_TEST_GCP_PROJECT is required to run BigQuery integration tests"
+        )
+    client: bigquery.Client = bigquery.Client(project=gcp_project)
+    job: bigquery.LoadJob = client.load_table_from_dataframe(
+        dataframe, table_id
+    )  # Make an API request.
+    job.result()  # Wait for the job to complete
+
+
+def clean_up_tables_with_prefix(connection_string: str, table_prefix: str) -> List[str]:
+    """Drop all tables starting with the provided table_prefix.
+    Note: Uses private method InferredAssetSqlDataConnector._introspect_db()
+    to get the table names to not duplicate code, but should be refactored in the
+    future to not use a private method.
+
+    Args:
+        connection_string: To connect to the database.
+        table_prefix: First characters of the tables you want to remove.
+
+    Returns:
+        List of deleted tables.
+    """
+    execution_engine: SqlAlchemyExecutionEngine = SqlAlchemyExecutionEngine(
+        connection_string=connection_string
+    )
+    data_connector = instantiate_class_from_config(
+        config={
+            "class_name": "InferredAssetSqlDataConnector",
+            "name": "temp_data_connector",
+        },
+        runtime_environment={
+            "execution_engine": execution_engine,
+            "datasource_name": "temp_datasource",
+        },
+        config_defaults={"module_name": "great_expectations.datasource.data_connector"},
+    )
+    introspection_output = data_connector._introspect_db()
+
+    tables_to_drop: List[str] = []
+    tables_dropped: List[str] = []
+
+    for table in introspection_output:
+        if table["table_name"].startswith(table_prefix):
+            tables_to_drop.append(table["table_name"])
+
+    connection = execution_engine.engine.connect()
+    for table_name in tables_to_drop:
         print(f"Dropping table {table_name}")
         connection.execute(f"DROP TABLE IF EXISTS {table_name}")
-        df = pd.read_csv(csv_path)
-        if not load_full_dataset:
-            # Improving test performance by only loading the first 10 rows of our test data into the db
-            df = df.head(10)
-        print(f"Creating table {table_name} from {csv_path}")
-        df.to_sql(name=table_name, con=engine, index=False)
-    except SQLAlchemyError as e:
-        logger.error(
-            f"""Docs integration tests encountered an error while loading test-data into test-database."""
-        )
-        raise
-    finally:
-        connection.close()
-        engine.dispose()
+        tables_dropped.append(table_name)
+
+    tables_skipped: List[str] = list(set(tables_to_drop) - set(tables_dropped))
+    if len(tables_skipped) > 0:
+        warnings.warn(f"Warning: Tables skipped: {tables_skipped}")
+
+    return tables_dropped
 
 
 @contextmanager
@@ -522,7 +743,7 @@ def check_athena_table_count(
         return len(result) == expected_table_count
     except SQLAlchemyError as e:
         logger.error(
-            f"""Docs integration tests encountered an error while loading test-data into test-database."""
+            """Docs integration tests encountered an error while loading test-data into test-database."""
         )
         raise
     finally:
@@ -554,3 +775,43 @@ def clean_athena_db(connection_string: str, db_name: str, table_to_keep: str) ->
     finally:
         connection.close()
         engine.dispose()
+
+
+def find_strings_in_nested_obj(obj: Any, target_strings: List[str]) -> bool:
+    """Recursively traverse a nested structure to find all strings in an input string.
+
+    Args:
+        obj (Any): The object to traverse (generally a dict to start with)
+        target_strings (List[str]): The collection of strings to find.
+
+    Returns:
+        True if ALL target strings are found. Otherwise, will return False.
+    """
+
+    strings: Set[str] = set(target_strings)
+
+    def _find_string(data: Any) -> bool:
+        if isinstance(data, list):
+            for val in data:
+                if _find_string(val):
+                    return True
+        elif isinstance(data, dict):
+            for key, val in data.items():
+                if _find_string(key) or _find_string(val):
+                    return True
+        elif isinstance(data, str):
+            string_to_remove: Optional[str] = None
+            for string in strings:
+                if string in data:
+                    string_to_remove = string
+                    break
+            if string_to_remove:
+                strings.remove(string_to_remove)
+                if not strings:
+                    return True
+        return False
+
+    success: bool = _find_string(obj)
+    if not success:
+        logger.info(f"Could not find the following target strings: {strings}")
+    return success
